@@ -57,28 +57,43 @@ G_DEFINE_TYPE (GsAppList, gs_app_list, G_TYPE_OBJECT)
  * Applications that have the application ID lazy-loaded will always be addded
  * to the list, and to clean these up the plugin loader will also call the
  * gs_app_list_filter_duplicates() method when all plugins have run.
+ *
+ * Since: 3.22
  **/
 void
 gs_app_list_add (GsAppList *list, GsApp *app)
 {
 	const gchar *id;
+	guint i;
 
 	g_return_if_fail (GS_IS_APP_LIST (list));
 	g_return_if_fail (GS_IS_APP (app));
 
 	/* if we're lazy-loading the ID then we can't filter for duplicates */
-	id = gs_app_get_id (app);
+	id = gs_app_get_unique_id (app);
 	if (id == NULL) {
 		g_ptr_array_add (list->array, g_object_ref (app));
 		return;
 	}
 
-	/* check for hash_by_id */
+	/* check for duplicate */
 	if (g_hash_table_lookup (list->hash_by_id, id) != NULL) {
 		g_debug ("not adding duplicate %s", id);
 		return;
 	}
 
+	/* check for duplicate using globs (slower) */
+	for (i = 0; i < list->array->len; i++) {
+		GsApp *app_tmp = g_ptr_array_index (list->array, i);
+		if (as_utils_unique_id_equal (gs_app_get_unique_id (app),
+					      gs_app_get_unique_id (app_tmp))) {
+			g_debug ("not adding duplicate %s as %s exists",
+				 gs_app_get_unique_id (app),
+				 gs_app_get_unique_id (app_tmp));
+			return;
+		}
+	}
+
 	/* just use the ref */
 	g_ptr_array_add (list->array, g_object_ref (app));
 	g_hash_table_insert (list->hash_by_id, (gpointer) id, (gpointer) app);
@@ -92,6 +107,8 @@ gs_app_list_add (GsAppList *list, GsApp *app)
  * Gets an application at a specific position in the list.
  *
  * Returns: (transfer none): a #GsApp, or %NULL if invalid
+ *
+ * Since: 3.22
  **/
 GsApp *
 gs_app_list_index (GsAppList *list, guint idx)
@@ -106,6 +123,8 @@ gs_app_list_index (GsAppList *list, guint idx)
  * Gets the length of the application list.
  *
  * Returns: Integer
+ *
+ * Since: 3.22
  **/
 guint
 gs_app_list_length (GsAppList *list)
@@ -119,6 +138,8 @@ gs_app_list_length (GsAppList *list)
  * @list: A #GsAppList
  *
  * Removes all applications from the list.
+ *
+ * Since: 3.22
  **/
 void
 gs_app_list_remove_all (GsAppList *list)
@@ -135,6 +156,8 @@ gs_app_list_remove_all (GsAppList *list)
  * @user_data: the user pointer to pass to @func
  *
  * If func() returns TRUE for the GsApp, then the app is kept.
+ *
+ * Since: 3.22
  **/
 void
 gs_app_list_filter (GsAppList *list, GsAppListFilterFunc func, gpointer user_data)
@@ -178,6 +201,8 @@ gs_app_list_sort_cb (gconstpointer a, gconstpointer b, gpointer user_data)
  * @func: A #GCompareFunc
  *
  * Sorts the application list.
+ *
+ * Since: 3.22
  **/
 void
 gs_app_list_sort (GsAppList *list, GsAppListSortFunc func, gpointer user_data)
@@ -210,6 +235,8 @@ gs_app_list_randomize_cb (gconstpointer a, gconstpointer b, gpointer user_data)
  *
  * Randomize the order of the list, but don't change the order until
  * the next day.
+ *
+ * Since: 3.22
  **/
 void
 gs_app_list_randomize (GsAppList *list)
@@ -226,12 +253,12 @@ gs_app_list_randomize (GsAppList *list)
 	key = g_strdup_printf ("Plugin::sort-key[%p]", list);
 	rand = g_rand_new ();
 	date = g_date_time_new_now_utc ();
-	g_rand_set_seed (rand, g_date_time_get_day_of_year (date));
+	g_rand_set_seed (rand, (guint32) g_date_time_get_day_of_year (date));
 	for (i = 0; i < gs_app_list_length (list); i++) {
 		app = gs_app_list_index (list, i);
-		sort_key[0] = g_rand_int_range (rand, (gint32) 'A', (gint32) 'Z');
-		sort_key[1] = g_rand_int_range (rand, (gint32) 'A', (gint32) 'Z');
-		sort_key[2] = g_rand_int_range (rand, (gint32) 'A', (gint32) 'Z');
+		sort_key[0] = (gchar) g_rand_int_range (rand, (gint32) 'A', (gint32) 'Z');
+		sort_key[1] = (gchar) g_rand_int_range (rand, (gint32) 'A', (gint32) 'Z');
+		sort_key[2] = (gchar) g_rand_int_range (rand, (gint32) 'A', (gint32) 'Z');
 		gs_app_set_metadata (app, key, sort_key);
 	}
 	g_ptr_array_sort_with_data (list->array, gs_app_list_randomize_cb, list);
@@ -247,6 +274,8 @@ gs_app_list_randomize (GsAppList *list)
  * @list: A #GsAppList
  *
  * Filter any duplicate applications from the list.
+ *
+ * Since: 3.22
  **/
 void
 gs_app_list_filter_duplicates (GsAppList *list, GsAppListFilterFlags flags)
@@ -266,9 +295,9 @@ gs_app_list_filter_duplicates (GsAppList *list, GsAppListFilterFlags flags)
 				      g_free, (GDestroyNotify) g_object_unref);
 	for (i = 0; i < list->array->len; i++) {
 		app = gs_app_list_index (list, i);
-		id = gs_app_get_id (app);
+		id = gs_app_get_unique_id (app);
 		if (flags & GS_APP_LIST_FILTER_FLAG_PRIORITY)
-			id = gs_app_get_id_no_prefix (app);
+			id = gs_app_get_id (app);
 		if (id == NULL) {
 			g_autofree gchar *str = gs_app_to_string (app);
 			g_debug ("ignoring as no application id for: %s", str);
@@ -276,7 +305,7 @@ gs_app_list_filter_duplicates (GsAppList *list, GsAppListFilterFlags flags)
 		}
 		found = g_hash_table_lookup (hash, id);
 		if (found == NULL) {
-			g_debug ("found new %s", gs_app_get_id (app));
+			g_debug ("found new %s", id);
 			g_hash_table_insert (hash,
 					     g_strdup (id),
 					     g_object_ref (app));
@@ -288,7 +317,7 @@ gs_app_list_filter_duplicates (GsAppList *list, GsAppListFilterFlags flags)
 			if (gs_app_get_priority (app) >
 			    gs_app_get_priority (found)) {
 				g_debug ("using better %s (priority %u > %u)",
-					 gs_app_get_id (app),
+					 id,
 					 gs_app_get_priority (app),
 					 gs_app_get_priority (found));
 				g_hash_table_insert (hash,
@@ -297,12 +326,12 @@ gs_app_list_filter_duplicates (GsAppList *list, GsAppListFilterFlags flags)
 				continue;
 			}
 			g_debug ("ignoring worse duplicate %s (priority %u > %u)",
-				 gs_app_get_id (app),
+				 id,
 				 gs_app_get_priority (app),
 				 gs_app_get_priority (found));
 			continue;
 		}
-		g_debug ("ignoring duplicate %s", gs_app_get_id (app));
+		g_debug ("ignoring duplicate %s", id);
 		continue;
 	}
 
@@ -322,6 +351,8 @@ gs_app_list_filter_duplicates (GsAppList *list, GsAppListFilterFlags flags)
  * Returns a deep copy of the application list.
  *
  * Returns: A newly allocated #GsAppList
+ *
+ * Since: 3.22
  **/
 GsAppList *
 gs_app_list_copy (GsAppList *list)
@@ -368,6 +399,8 @@ gs_app_list_init (GsAppList *list)
  * Creates a new list.
  *
  * Returns: A newly allocated #GsAppList
+ *
+ * Since: 3.22
  **/
 GsAppList *
 gs_app_list_new (void)
