@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2012-2013 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2012-2016 Richard Hughes <richard@hughsie.com>
  * Copyright (C) 2013 Matthias Clasen <mclasen@redhat.com>
  *
  * Licensed under the GNU General Public License Version 2
@@ -46,16 +46,21 @@ typedef struct
 	GtkWidget	*spinner;
 	GtkWidget	*label;
 	GtkWidget	*checkbox;
-	GtkWidget	*label_tag_foreign;
-	GtkWidget	*label_tag_warning;
-	GtkWidget	*label_tag_webapp;
-	GtkWidget	*label_tag_nonfree;
-	GtkWidget	*label_tag_extension;
+	GtkWidget	*label_warning;
+	GtkWidget	*label_origin;
+	GtkWidget	*label_installed;
+	GtkWidget	*box_sandboxed;
+	GtkWidget	*image_sandboxed;
 	gboolean	 colorful;
+	gboolean	 show_folders;
+	gboolean	 show_buttons;
+	gboolean	 show_sandbox;
+	gboolean	 show_source;
 	gboolean	 show_codec;
 	gboolean	 show_update;
 	gboolean	 selectable;
 	guint		 pending_refresh_id;
+	GSettings	*settings;
 } GsAppRowPrivate;
 
 G_DEFINE_TYPE_WITH_PRIVATE (GsAppRow, gs_app_row, GTK_TYPE_LIST_BOX_ROW)
@@ -83,7 +88,6 @@ gs_app_row_get_description (GsAppRow *app_row)
 {
 	GsAppRowPrivate *priv = gs_app_row_get_instance_private (app_row);
 	const gchar *tmp = NULL;
-	g_autofree gchar *escaped = NULL;
 
 	/* convert the markdown update description into PangoMarkup */
 	if (priv->show_update &&
@@ -94,8 +98,13 @@ gs_app_row_get_description (GsAppRow *app_row)
 			return g_string_new (tmp);
 	}
 
-	if (gs_app_get_state (priv->app) == AS_APP_STATE_UNAVAILABLE)
-		return g_string_new (gs_app_get_summary_missing (priv->app));
+	/* if missing summary is set, return it without escaping in order to
+	 * correctly show hyperlinks */
+	if (gs_app_get_state (priv->app) == AS_APP_STATE_UNAVAILABLE) {
+		tmp = gs_app_get_summary_missing (priv->app);
+		if (tmp != NULL && tmp[0] != '\0')
+			return g_string_new (tmp);
+	}
 
 	/* try all these things in order */
 	if (tmp == NULL || (tmp != NULL && tmp[0] == '\0'))
@@ -106,156 +115,58 @@ gs_app_row_get_description (GsAppRow *app_row)
 		tmp = gs_app_get_name (priv->app);
 	if (tmp == NULL)
 		return NULL;
-	escaped = g_markup_escape_text (tmp, -1);
-	return g_string_new (escaped);
+	return g_string_new (tmp);
 }
 
-/**
- * gs_app_row_refresh:
- **/
-void
-gs_app_row_refresh (GsAppRow *app_row)
+static gchar *
+gs_app_row_format_version_update (GsApp *app)
+{
+	const gchar *tmp;
+	const gchar *version_current = NULL;
+	const gchar *version_update = NULL;
+
+	/* current version */
+	tmp = gs_app_get_version_ui (app);
+	if (tmp != NULL && tmp[0] != '\0')
+		version_current = tmp;
+
+	/* update version */
+	tmp = gs_app_get_update_version_ui (app);
+	if (tmp != NULL && tmp[0] != '\0')
+		version_update = tmp;
+
+	/* have both */
+	if (version_current != NULL && version_update != NULL) {
+		return g_strdup_printf ("%s ▶ %s",
+					version_current,
+					version_update);
+	}
+
+	/* just update */
+	if (version_update)
+		return g_strdup (version_update);
+
+	/* we have nothing, nada, zilch */
+	return NULL;
+}
+
+static void
+gs_app_row_refresh_button (GsAppRow *app_row, gboolean missing_search_result)
 {
 	GsAppRowPrivate *priv = gs_app_row_get_instance_private (app_row);
 	GtkStyleContext *context;
-	GString *str = NULL;
 
-	if (priv->app == NULL)
+	/* disabled */
+	if (!priv->show_buttons) {
+		gtk_widget_set_visible (priv->button, FALSE);
 		return;
-
-	/* do a fill bar for the current progress */
-	switch (gs_app_get_state (priv->app)) {
-	case AS_APP_STATE_INSTALLING:
-		gs_progress_button_set_progress (GS_PROGRESS_BUTTON (priv->button),
-		                                 gs_app_get_progress (priv->app));
-		gs_progress_button_set_show_progress (GS_PROGRESS_BUTTON (priv->button), TRUE);
-		break;
-	default:
-		gs_progress_button_set_show_progress (GS_PROGRESS_BUTTON (priv->button), FALSE);
-		break;
 	}
 
-	/* join the description lines */
-	str = gs_app_row_get_description (app_row);
-	if (str != NULL) {
-		as_utils_string_replace (str, "\n", " ");
-		gtk_label_set_markup (GTK_LABEL (priv->description_label), str->str);
-		g_string_free (str, TRUE);
-	} else {
-		gtk_label_set_text (GTK_LABEL (priv->description_label), NULL);
-	}
-
-	/* add warning */
-	if (gs_app_get_kind (priv->app) == AS_APP_KIND_FIRMWARE) {
-		gtk_label_set_text (GTK_LABEL (priv->label_tag_warning),
-				    /* TRANSLATORS: during the update the device
-				     * will restart into a special update-only mode */
-				    _("Device cannot be used during update."));
-		gtk_widget_show (priv->label_tag_warning);
-	}
-
-	/* add tags */
-	if (priv->show_update) {
-		gtk_widget_set_visible (priv->label_tag_webapp, FALSE);
-		gtk_widget_set_visible (priv->label_tag_nonfree, FALSE);
-		gtk_widget_set_visible (priv->label_tag_foreign, FALSE);
-		gtk_widget_set_visible (priv->label_tag_extension, FALSE);
-	} else {
-		switch (gs_app_get_kind (priv->app)) {
-		case AS_APP_KIND_UNKNOWN:
-			gtk_widget_set_visible (priv->label_tag_webapp, FALSE);
-			gtk_widget_set_visible (priv->label_tag_nonfree, FALSE);
-			gtk_widget_set_visible (priv->label_tag_foreign, FALSE);
-			gtk_widget_set_visible (priv->label_tag_extension, FALSE);
-			break;
-		case AS_APP_KIND_WEB_APP:
-			gtk_widget_set_visible (priv->label_tag_webapp, TRUE);
-			gtk_widget_set_visible (priv->label_tag_nonfree, FALSE);
-			gtk_widget_set_visible (priv->label_tag_foreign, FALSE);
-			gtk_widget_set_visible (priv->label_tag_extension, FALSE);
-			break;
-		case AS_APP_KIND_SHELL_EXTENSION:
-			gtk_widget_set_visible (priv->label_tag_webapp, FALSE);
-			gtk_widget_set_visible (priv->label_tag_nonfree, FALSE);
-			gtk_widget_set_visible (priv->label_tag_foreign, FALSE);
-			gtk_widget_set_visible (priv->label_tag_extension, TRUE);
-			break;
-		default:
-			gtk_widget_set_visible (priv->label_tag_webapp, FALSE);
-			gtk_widget_set_visible (priv->label_tag_extension, FALSE);
-			gtk_widget_set_visible (priv->label_tag_nonfree,
-						!gs_app_get_license_is_free (priv->app));
-			gtk_widget_set_visible (priv->label_tag_foreign,
-						!gs_app_has_quirk (priv->app,
-								   AS_APP_QUIRK_PROVENANCE));
-			break;
-		}
-	}
-
-	gtk_label_set_label (GTK_LABEL (priv->name_label),
-			     gs_app_get_name (priv->app));
-	if (priv->show_update &&
-	    (gs_app_get_state (priv->app) == AS_APP_STATE_UPDATABLE ||
-	     gs_app_get_state (priv->app) == AS_APP_STATE_UPDATABLE_LIVE)) {
-		gtk_widget_show (priv->version_label);
-		gtk_widget_hide (priv->star);
-		gtk_label_set_label (GTK_LABEL (priv->version_label),
-				     gs_app_get_update_version_ui (priv->app));
-	} else {
-		gtk_widget_hide (priv->version_label);
-		if (gs_app_get_state (priv->app) == AS_APP_STATE_UNAVAILABLE ||
-		    gs_app_get_rating (priv->app) <= 0) {
-			gtk_widget_hide (priv->star);
-		} else {
-			gtk_widget_show (priv->star);
-			gtk_widget_set_sensitive (priv->star, FALSE);
-			gs_star_widget_set_rating (GS_STAR_WIDGET (priv->star),
-						   gs_app_get_rating (priv->app));
-		}
-		gtk_label_set_label (GTK_LABEL (priv->version_label),
-				     gs_app_get_version_ui (priv->app));
-	}
-
-	if (priv->show_update || priv->show_codec) {
-		gtk_widget_hide (priv->folder_label);
-	} else {
-		g_autoptr(GsFolders) folders = NULL;
-		const gchar *folder;
-		folders = gs_folders_get ();
-		folder = gs_folders_get_app_folder (folders, gs_app_get_id (priv->app), gs_app_get_categories (priv->app));
-		if (folder)
-			folder = gs_folders_get_folder_name (folders, folder);
-
-		/* we overwrite this for some apps */
-		if (folder == NULL)
-			folder = gs_app_get_metadata_item (priv->app, "X-XdgApp-Tags");
-
-		gtk_label_set_label (GTK_LABEL (priv->folder_label), folder);
-		gtk_widget_set_visible (priv->folder_label, folder != NULL);
-	}
-
-	if (gs_app_get_pixbuf (priv->app) != NULL)
-		gs_image_set_from_pixbuf (GTK_IMAGE (priv->image),
-					  gs_app_get_pixbuf (priv->app));
-
-	context = gtk_widget_get_style_context (priv->image);
-	if (gs_app_get_state (priv->app) == AS_APP_STATE_UNAVAILABLE)
-		gtk_style_context_add_class (context, "dimmer-label");
-	else
-		gtk_style_context_remove_class (context, "dimmer-label");
-
-	gtk_widget_set_visible (priv->button, FALSE);
-	gtk_widget_set_sensitive (priv->button, TRUE);
-	gtk_widget_set_visible (priv->spinner, FALSE);
-	gtk_widget_set_visible (priv->label, FALSE);
-
-	context = gtk_widget_get_style_context (priv->button);
-	gtk_style_context_remove_class (context, "destructive-action");
-
+	/* label */
 	switch (gs_app_get_state (priv->app)) {
 	case AS_APP_STATE_UNAVAILABLE:
 		gtk_widget_set_visible (priv->button, TRUE);
-		if (gs_app_get_url (priv->app, AS_URL_KIND_MISSING) != NULL) {
+		if (missing_search_result) {
 			/* TRANSLATORS: this is a button next to the search results that
 			 * allows the application to be easily installed */
 			gtk_button_set_label (GTK_BUTTON (priv->button), _("Visit website"));
@@ -267,14 +178,12 @@ gs_app_row_refresh (GsAppRow *app_row)
 		}
 		break;
 	case AS_APP_STATE_QUEUED_FOR_INSTALL:
-		gtk_widget_set_visible (priv->label, TRUE);
 		gtk_widget_set_visible (priv->button, TRUE);
 		/* TRANSLATORS: this is a button next to the search results that
 		 * allows to cancel a queued install of the application */
 		gtk_button_set_label (GTK_BUTTON (priv->button), _("Cancel"));
 		/* TRANSLATORS: this is a label that describes an application
 		 * that has been queued for installation */
-		gtk_label_set_label (GTK_LABEL (priv->label), _("Pending"));
 		break;
 	case AS_APP_STATE_AVAILABLE:
 	case AS_APP_STATE_AVAILABLE_LOCAL:
@@ -293,8 +202,6 @@ gs_app_row_refresh (GsAppRow *app_row)
 			/* TRANSLATORS: this is a button next to the search results that
 			 * allows the application to be easily removed */
 			gtk_button_set_label (GTK_BUTTON (priv->button), _("Remove"));
-			if (priv->colorful)
-				gtk_style_context_add_class (context, "destructive-action");
 		}
 		break;
 	case AS_APP_STATE_UPDATABLE:
@@ -304,21 +211,15 @@ gs_app_row_refresh (GsAppRow *app_row)
 		/* TRANSLATORS: this is a button next to the search results that
 		 * allows the application to be easily removed */
 		gtk_button_set_label (GTK_BUTTON (priv->button), _("Remove"));
-		if (priv->colorful)
-			gtk_style_context_add_class (context, "destructive-action");
 		break;
 	case AS_APP_STATE_INSTALLING:
 		gtk_widget_set_visible (priv->button, TRUE);
-		gtk_widget_set_sensitive (priv->button, FALSE);
 		/* TRANSLATORS: this is a button next to the search results that
 		 * shows the status of an application being installed */
 		gtk_button_set_label (GTK_BUTTON (priv->button), _("Installing"));
 		break;
 	case AS_APP_STATE_REMOVING:
-		gtk_spinner_start (GTK_SPINNER (priv->spinner));
-		gtk_widget_set_visible (priv->spinner, TRUE);
 		gtk_widget_set_visible (priv->button, TRUE);
-		gtk_widget_set_sensitive (priv->button, FALSE);
 		/* TRANSLATORS: this is a button next to the search results that
 		 * shows the status of an application being erased */
 		gtk_button_set_label (GTK_BUTTON (priv->button), _("Removing"));
@@ -327,6 +228,235 @@ gs_app_row_refresh (GsAppRow *app_row)
 		break;
 	}
 
+	/* visible */
+	switch (gs_app_get_state (priv->app)) {
+	case AS_APP_STATE_UNAVAILABLE:
+	case AS_APP_STATE_QUEUED_FOR_INSTALL:
+	case AS_APP_STATE_AVAILABLE:
+	case AS_APP_STATE_AVAILABLE_LOCAL:
+	case AS_APP_STATE_UPDATABLE_LIVE:
+	case AS_APP_STATE_INSTALLING:
+	case AS_APP_STATE_REMOVING:
+		gtk_widget_set_visible (priv->button, TRUE);
+		break;
+	case AS_APP_STATE_UPDATABLE:
+	case AS_APP_STATE_INSTALLED:
+		gtk_widget_set_visible (priv->button,
+					!gs_app_has_quirk (priv->app,
+							   AS_APP_QUIRK_COMPULSORY));
+		break;
+	default:
+		gtk_widget_set_visible (priv->button, FALSE);
+		break;
+	}
+
+	/* colorful */
+	context = gtk_widget_get_style_context (priv->button);
+	if (!priv->colorful) {
+		gtk_style_context_remove_class (context, "destructive-action");
+	} else {
+		switch (gs_app_get_state (priv->app)) {
+		case AS_APP_STATE_UPDATABLE:
+		case AS_APP_STATE_INSTALLED:
+		case AS_APP_STATE_UPDATABLE_LIVE:
+			gtk_style_context_remove_class (context, "destructive-action");
+			break;
+		default:
+			gtk_style_context_add_class (context, "destructive-action");
+			break;
+		}
+	}
+
+	/* always insensitive when in selection mode */
+	if (priv->selectable) {
+		gtk_widget_set_sensitive (priv->button, FALSE);
+	} else {
+		switch (gs_app_get_state (priv->app)) {
+		case AS_APP_STATE_INSTALLING:
+		case AS_APP_STATE_REMOVING:
+			gtk_widget_set_sensitive (priv->button, FALSE);
+			break;
+		default:
+			gtk_widget_set_sensitive (priv->button, TRUE);
+			break;
+		}
+	}
+}
+
+void
+gs_app_row_refresh (GsAppRow *app_row)
+{
+	GsAppRowPrivate *priv = gs_app_row_get_instance_private (app_row);
+	GtkStyleContext *context;
+	GString *str = NULL;
+	const gchar *tmp;
+	gboolean missing_search_result;
+
+	if (priv->app == NULL)
+		return;
+
+	/* is this a missing search result from the extras page? */
+	missing_search_result = (gs_app_get_state (priv->app) == AS_APP_STATE_UNAVAILABLE &&
+	                         gs_app_get_url (priv->app, AS_URL_KIND_MISSING) != NULL);
+
+	/* do a fill bar for the current progress */
+	switch (gs_app_get_state (priv->app)) {
+	case AS_APP_STATE_INSTALLING:
+		gs_progress_button_set_progress (GS_PROGRESS_BUTTON (priv->button),
+		                                 gs_app_get_progress (priv->app));
+		gs_progress_button_set_show_progress (GS_PROGRESS_BUTTON (priv->button), TRUE);
+		break;
+	default:
+		gs_progress_button_set_show_progress (GS_PROGRESS_BUTTON (priv->button), FALSE);
+		break;
+	}
+
+	/* join the description lines */
+	str = gs_app_row_get_description (app_row);
+	if (str != NULL) {
+		as_utils_string_replace (str, "\n", " ");
+		gtk_label_set_label (GTK_LABEL (priv->description_label), str->str);
+		g_string_free (str, TRUE);
+	} else {
+		gtk_label_set_text (GTK_LABEL (priv->description_label), NULL);
+	}
+
+	/* add warning */
+	if (gs_app_get_kind (priv->app) == AS_APP_KIND_FIRMWARE) {
+		gtk_label_set_text (GTK_LABEL (priv->label_warning),
+				    /* TRANSLATORS: during the update the device
+				     * will restart into a special update-only mode */
+				    _("Device cannot be used during update."));
+		gtk_widget_show (priv->label_warning);
+	}
+
+	/* where did this app come from */
+	if (priv->show_source) {
+		tmp = gs_app_get_origin_hostname (priv->app);
+		if (tmp != NULL) {
+			g_autofree gchar *origin_tmp = NULL;
+			/* TRANSLATORS: this refers to where the app came from */
+			origin_tmp = g_strdup_printf ("%s: %s", _("Source"), tmp);
+			gtk_label_set_label (GTK_LABEL (priv->label_origin), origin_tmp);
+		}
+		gtk_widget_set_visible (priv->label_origin, tmp != NULL);
+	} else {
+		gtk_widget_set_visible (priv->label_origin, FALSE);
+	}
+
+	/* sandboxed */
+	if (priv->show_sandbox) {
+		if (gs_app_get_kudos (priv->app) & GS_APP_KUDO_SANDBOXED_SECURE) {
+			gtk_widget_set_visible (priv->box_sandboxed, TRUE);
+			gtk_image_set_from_icon_name (GTK_IMAGE (priv->image_sandboxed),
+						      "security-high-symbolic",
+						      GTK_ICON_SIZE_SMALL_TOOLBAR);
+		} else if (gs_app_get_kudos (priv->app) & GS_APP_KUDO_SANDBOXED) {
+			gtk_widget_set_visible (priv->box_sandboxed, TRUE);
+			gtk_image_set_from_icon_name (GTK_IMAGE (priv->image_sandboxed),
+						      "security-medium-symbolic",
+						      GTK_ICON_SIZE_SMALL_TOOLBAR);
+		} else {
+			gtk_widget_set_visible (priv->box_sandboxed, FALSE);
+		}
+	} else {
+		gtk_widget_set_visible (priv->box_sandboxed, FALSE);
+	}
+
+	/* installed tag */
+	if (!priv->show_buttons) {
+		switch (gs_app_get_state (priv->app)) {
+		case AS_APP_STATE_UPDATABLE:
+		case AS_APP_STATE_UPDATABLE_LIVE:
+		case AS_APP_STATE_INSTALLED:
+			gtk_widget_set_visible (priv->label_installed, TRUE);
+			break;
+		default:
+			gtk_widget_set_visible (priv->label_installed, FALSE);
+			break;
+		}
+	} else {
+		gtk_widget_set_visible (priv->label_installed, FALSE);
+	}
+
+	gtk_label_set_label (GTK_LABEL (priv->name_label),
+			     gs_app_get_name (priv->app));
+	if (priv->show_update &&
+	    (gs_app_get_state (priv->app) == AS_APP_STATE_UPDATABLE ||
+	     gs_app_get_state (priv->app) == AS_APP_STATE_UPDATABLE_LIVE)) {
+		g_autofree gchar *verstr = NULL;
+		verstr = gs_app_row_format_version_update (priv->app);
+		gtk_label_set_label (GTK_LABEL (priv->version_label), verstr);
+		gtk_widget_set_visible (priv->version_label, verstr != NULL);
+		gtk_widget_hide (priv->star);
+	} else {
+		gtk_widget_hide (priv->version_label);
+		if (missing_search_result || gs_app_get_rating (priv->app) <= 0) {
+			gtk_widget_hide (priv->star);
+		} else {
+			gtk_widget_show (priv->star);
+			gtk_widget_set_sensitive (priv->star, FALSE);
+			gs_star_widget_set_rating (GS_STAR_WIDGET (priv->star),
+						   gs_app_get_rating (priv->app));
+		}
+		gtk_label_set_label (GTK_LABEL (priv->version_label),
+				     gs_app_get_version_ui (priv->app));
+	}
+
+	/* folders */
+	if (priv->show_folders &&
+	    gs_utils_is_current_desktop ("GNOME") &&
+	    g_settings_get_boolean (priv->settings, "show-folder-management")) {
+		g_autoptr(GsFolders) folders = NULL;
+		const gchar *folder;
+		folders = gs_folders_get ();
+		folder = gs_folders_get_app_folder (folders,
+						    gs_app_get_id (priv->app),
+						    gs_app_get_categories (priv->app));
+		if (folder != NULL)
+			folder = gs_folders_get_folder_name (folders, folder);
+		gtk_label_set_label (GTK_LABEL (priv->folder_label), folder);
+		gtk_widget_set_visible (priv->folder_label, folder != NULL);
+	} else {
+		gtk_widget_hide (priv->folder_label);
+	}
+
+	/* pixbuf */
+	if (gs_app_get_pixbuf (priv->app) != NULL)
+		gs_image_set_from_pixbuf (GTK_IMAGE (priv->image),
+					  gs_app_get_pixbuf (priv->app));
+
+	context = gtk_widget_get_style_context (priv->image);
+	if (missing_search_result)
+		gtk_style_context_add_class (context, "dimmer-label");
+	else
+		gtk_style_context_remove_class (context, "dimmer-label");
+
+	/* pending label */
+	switch (gs_app_get_state (priv->app)) {
+	case AS_APP_STATE_QUEUED_FOR_INSTALL:
+		gtk_widget_set_visible (priv->label, TRUE);
+		gtk_label_set_label (GTK_LABEL (priv->label), _("Pending"));
+		break;
+	default:
+		gtk_widget_set_visible (priv->label, FALSE);
+		break;
+	}
+
+	/* spinner */
+	switch (gs_app_get_state (priv->app)) {
+	case AS_APP_STATE_REMOVING:
+		gtk_spinner_start (GTK_SPINNER (priv->spinner));
+		gtk_widget_set_visible (priv->spinner, TRUE);
+		break;
+	default:
+		gtk_widget_set_visible (priv->spinner, FALSE);
+		break;
+	}
+
+	/* button */
+	gs_app_row_refresh_button (app_row, missing_search_result);
+
 	/* hide buttons in the update list, unless the app is live updatable */
 	switch (gs_app_get_state (priv->app)) {
 	case AS_APP_STATE_UPDATABLE_LIVE:
@@ -338,12 +468,12 @@ gs_app_row_refresh (GsAppRow *app_row)
 		break;
 	}
 
+	/* checkbox */
 	if (priv->selectable) {
 		if (gs_app_get_kind (priv->app) == AS_APP_KIND_DESKTOP ||
 		    gs_app_get_kind (priv->app) == AS_APP_KIND_RUNTIME ||
 		    gs_app_get_kind (priv->app) == AS_APP_KIND_WEB_APP)
 			gtk_widget_set_visible (priv->checkbox, TRUE);
-		gtk_widget_set_sensitive (priv->button, FALSE);
 	} else {
 		gtk_widget_set_visible (priv->checkbox, FALSE);
 	}
@@ -383,9 +513,17 @@ gs_app_row_unreveal (GsAppRow *app_row)
 	gtk_revealer_set_reveal_child (GTK_REVEALER (revealer), FALSE);
 }
 
-/**
- * gs_app_row_get_app:
- **/
+static void
+settings_changed_cb (GsAppRow *self,
+		     const gchar *key,
+		     gpointer data)
+{
+	if (g_strcmp0 (key, "show-nonfree-ui") == 0 ||
+	    g_strcmp0 (key, "show-folder-management") == 0) {
+		gs_app_row_refresh (self);
+	}
+}
+
 GsApp *
 gs_app_row_get_app (GsAppRow *app_row)
 {
@@ -394,9 +532,6 @@ gs_app_row_get_app (GsAppRow *app_row)
 	return priv->app;
 }
 
-/**
- * gs_app_row_refresh_idle_cb:
- **/
 static gboolean
 gs_app_row_refresh_idle_cb (gpointer user_data)
 {
@@ -407,9 +542,6 @@ gs_app_row_refresh_idle_cb (gpointer user_data)
 	return FALSE;
 }
 
-/**
- * gs_app_row_notify_props_changed_cb:
- **/
 static void
 gs_app_row_notify_props_changed_cb (GsApp *app,
 				    GParamSpec *pspec,
@@ -421,9 +553,6 @@ gs_app_row_notify_props_changed_cb (GsApp *app,
 	priv->pending_refresh_id = g_idle_add (gs_app_row_refresh_idle_cb, app_row);
 }
 
-/**
- * gs_app_row_set_app:
- **/
 static void
 gs_app_row_set_app (GsAppRow *app_row, GsApp *app)
 {
@@ -443,15 +572,14 @@ gs_app_row_set_app (GsAppRow *app_row, GsApp *app)
 	gs_app_row_refresh (app_row);
 }
 
-/**
- * gs_app_row_destroy:
- **/
 static void
 gs_app_row_destroy (GtkWidget *object)
 {
 	GsAppRow *app_row = GS_APP_ROW (object);
 	GsAppRowPrivate *priv = gs_app_row_get_instance_private (app_row);
 
+	g_clear_object (&priv->settings);
+
 	if (priv->app)
 		g_signal_handlers_disconnect_by_func (priv->app, gs_app_row_notify_props_changed_cb, app_row);
 
@@ -538,11 +666,11 @@ gs_app_row_class_init (GsAppRowClass *klass)
 	gtk_widget_class_bind_template_child_private (widget_class, GsAppRow, spinner);
 	gtk_widget_class_bind_template_child_private (widget_class, GsAppRow, label);
 	gtk_widget_class_bind_template_child_private (widget_class, GsAppRow, checkbox);
-	gtk_widget_class_bind_template_child_private (widget_class, GsAppRow, label_tag_warning);
-	gtk_widget_class_bind_template_child_private (widget_class, GsAppRow, label_tag_foreign);
-	gtk_widget_class_bind_template_child_private (widget_class, GsAppRow, label_tag_webapp);
-	gtk_widget_class_bind_template_child_private (widget_class, GsAppRow, label_tag_nonfree);
-	gtk_widget_class_bind_template_child_private (widget_class, GsAppRow, label_tag_extension);
+	gtk_widget_class_bind_template_child_private (widget_class, GsAppRow, label_warning);
+	gtk_widget_class_bind_template_child_private (widget_class, GsAppRow, label_origin);
+	gtk_widget_class_bind_template_child_private (widget_class, GsAppRow, label_installed);
+	gtk_widget_class_bind_template_child_private (widget_class, GsAppRow, box_sandboxed);
+	gtk_widget_class_bind_template_child_private (widget_class, GsAppRow, image_sandboxed);
 }
 
 static void
@@ -564,13 +692,18 @@ gs_app_row_init (GsAppRow *app_row)
 
 	gtk_widget_set_has_window (GTK_WIDGET (app_row), FALSE);
 	gtk_widget_init_template (GTK_WIDGET (app_row));
+	gs_star_widget_set_icon_size (GS_STAR_WIDGET (priv->star), 12);
 
 	priv->colorful = TRUE;
+	priv->settings = g_settings_new ("org.gnome.software");
 
 	g_signal_connect (priv->button, "clicked",
 			  G_CALLBACK (button_clicked), app_row);
 	g_signal_connect (priv->checkbox, "toggled",
 			  G_CALLBACK (checkbox_toggled), app_row);
+	g_signal_connect_swapped (priv->settings, "changed",
+				  G_CALLBACK (settings_changed_cb),
+				  app_row);
 }
 
 void
@@ -585,8 +718,7 @@ gs_app_row_set_size_groups (GsAppRow *app_row,
 }
 
 void
-gs_app_row_set_colorful (GsAppRow *app_row,
-			    gboolean     colorful)
+gs_app_row_set_colorful (GsAppRow *app_row, gboolean colorful)
 {
 	GsAppRowPrivate *priv = gs_app_row_get_instance_private (app_row);
 
@@ -594,6 +726,42 @@ gs_app_row_set_colorful (GsAppRow *app_row,
 	gs_app_row_refresh (app_row);
 }
 
+void
+gs_app_row_set_show_folders (GsAppRow *app_row, gboolean show_folders)
+{
+	GsAppRowPrivate *priv = gs_app_row_get_instance_private (app_row);
+
+	priv->show_folders = show_folders;
+	gs_app_row_refresh (app_row);
+}
+
+void
+gs_app_row_set_show_buttons (GsAppRow *app_row, gboolean show_buttons)
+{
+	GsAppRowPrivate *priv = gs_app_row_get_instance_private (app_row);
+
+	priv->show_buttons = show_buttons;
+	gs_app_row_refresh (app_row);
+}
+
+void
+gs_app_row_set_show_sandbox (GsAppRow *app_row, gboolean show_sandbox)
+{
+	GsAppRowPrivate *priv = gs_app_row_get_instance_private (app_row);
+
+	priv->show_sandbox = show_sandbox;
+	gs_app_row_refresh (app_row);
+}
+
+void
+gs_app_row_set_show_source (GsAppRow *app_row, gboolean show_source)
+{
+	GsAppRowPrivate *priv = gs_app_row_get_instance_private (app_row);
+
+	priv->show_source = show_source;
+	gs_app_row_refresh (app_row);
+}
+
 void
 gs_app_row_set_show_codec (GsAppRow *app_row, gboolean show_codec)
 {
