@@ -27,8 +27,6 @@
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <appstream-glib.h>
 
-#include "gs-review.h"
-
 G_BEGIN_DECLS
 
 #define GS_TYPE_APP (gs_app_get_type ())
@@ -105,17 +103,26 @@ gchar		*gs_app_to_string		(GsApp		*app);
 const gchar	*gs_app_get_id			(GsApp		*app);
 void		 gs_app_set_id			(GsApp		*app,
 						 const gchar	*id);
-const gchar	*gs_app_get_id_no_prefix	(GsApp		*app);
 AsAppKind	 gs_app_get_kind		(GsApp		*app);
 void		 gs_app_set_kind		(GsApp		*app,
 						 AsAppKind	 kind);
 AsAppState	 gs_app_get_state		(GsApp		*app);
 void		 gs_app_set_state		(GsApp		*app,
 						 AsAppState	 state);
+AsAppScope	 gs_app_get_scope		(GsApp		*app);
+void		 gs_app_set_scope		(GsApp		*app,
+						 AsAppScope	 scope);
+AsBundleKind	 gs_app_get_bundle_kind		(GsApp		*app);
+void		 gs_app_set_bundle_kind		(GsApp		*app,
+						 AsBundleKind	 bundle_kind);
 void		 gs_app_set_state_recover	(GsApp		*app);
 guint		 gs_app_get_progress		(GsApp		*app);
 void		 gs_app_set_progress		(GsApp		*app,
 						 guint		 percentage);
+const gchar	*gs_app_get_unique_id		(GsApp		*app);
+const gchar	*gs_app_get_branch		(GsApp		*app);
+void		 gs_app_set_branch		(GsApp		*app,
+						 const gchar	*branch);
 const gchar	*gs_app_get_name		(GsApp		*app);
 void		 gs_app_set_name		(GsApp		*app,
 						 GsAppQuality	 quality,
@@ -214,9 +221,9 @@ void		 gs_app_set_review_ratings	(GsApp		*app,
 						 GArray		*review_ratings);
 GPtrArray	*gs_app_get_reviews		(GsApp		*app);
 void		 gs_app_add_review		(GsApp		*app,
-						 GsReview	*review);
+						 AsReview	*review);
 void		 gs_app_remove_review		(GsApp		*app,
-						 GsReview	*review);
+						 AsReview	*review);
 guint64		 gs_app_get_size_installed	(GsApp		*app);
 void		 gs_app_set_size_installed	(GsApp		*app,
 						 guint64	 size_installed);
@@ -267,6 +274,7 @@ void		 gs_app_add_quirk		(GsApp		*app,
 						 AsAppQuirk	 quirk);
 void		 gs_app_remove_quirk		(GsApp		*app,
 						 AsAppQuirk	 quirk);
+gboolean	 gs_app_is_installed		(GsApp		*app);
 G_END_DECLS
 
 #endif /* __GS_APP_H */
