@@ -108,6 +108,8 @@ gs_application_init (GsApplication *application)
 		  _("Show verbose debugging information"), NULL },
 		{ "profile", 0, 0, G_OPTION_ARG_NONE, NULL,
 		  _("Show profiling information for the service"), NULL },
+		{ "quit", 0, 0, G_OPTION_ARG_NONE, NULL,
+		  _("Quit the running instance"), NULL },
 		{ "prefer-local", '\0', 0, G_OPTION_ARG_NONE, NULL,
 		  _("Prefer local file sources to AppStream"), NULL },
 		{ "version", 0, 0, G_OPTION_ARG_NONE, NULL,
@@ -198,16 +200,30 @@ static void
 gs_application_initialize_plugins (GsApplication *app)
 {
 	static gboolean initialized = FALSE;
+	g_auto(GStrv) plugin_blacklist = NULL;
+	g_auto(GStrv) plugin_whitelist = NULL;
 	g_autoptr(GError) error = NULL;
+	const gchar *tmp;
 
 	if (initialized)
 		return;
 
 	initialized = TRUE;
 
+	/* allow for debugging */
+	tmp = g_getenv ("GNOME_SOFTWARE_PLUGINS_BLACKLIST");
+	if (tmp != NULL)
+		plugin_blacklist = g_strsplit (tmp, ",", -1);
+	tmp = g_getenv ("GNOME_SOFTWARE_PLUGINS_WHITELIST");
+	if (tmp != NULL)
+		plugin_whitelist = g_strsplit (tmp, ",", -1);
+
 	app->plugin_loader = gs_plugin_loader_new ();
 	gs_plugin_loader_set_location (app->plugin_loader, NULL);
-	if (!gs_plugin_loader_setup (app->plugin_loader, NULL, &error)) {
+	if (!gs_plugin_loader_setup (app->plugin_loader,
+				     plugin_whitelist,
+				     plugin_blacklist,
+				     &error)) {
 		g_warning ("Failed to setup plugins: %s", error->message);
 		exit (1);
 	}
@@ -255,6 +271,8 @@ gs_application_show_first_run_dialog (GsApplication *app)
 		dialog = gs_first_run_dialog_new ();
 		gs_shell_modal_dialog_present (app->shell, GTK_DIALOG (dialog));
 		g_settings_set_boolean (app->settings, "first-run", FALSE);
+		g_signal_connect_swapped (dialog, "response",
+					  G_CALLBACK (gtk_widget_destroy), dialog);
 	}
 }
 
@@ -273,16 +291,6 @@ theme_changed (GtkSettings *settings, GParamSpec *pspec, GsApplication *app)
 	gtk_css_provider_load_from_file (app->provider, file, NULL);
 }
 
-static void
-css_error (GtkCssProvider *provider,
-           GtkCssSection  *section,
-           const GError   *error,
-           gpointer        data)
-{
-  if (!g_error_matches (error, GTK_CSS_PROVIDER_ERROR, GTK_CSS_PROVIDER_ERROR_DEPRECATED))
-    g_error ("CSS parsing error: %s", error->message);
-}
-
 static void
 gs_application_initialize_ui (GsApplication *app)
 {
@@ -299,11 +307,6 @@ gs_application_initialize_ui (GsApplication *app)
 						   GTK_STYLE_PROVIDER (app->provider),
 						   GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 
-	/* This is to avoid CSS deprecation warnings until we can update
-	 * the CSS to not use deprecated selectors.
-	 */
-	g_signal_connect (app->provider, "parsing-error", G_CALLBACK (css_error), NULL);
-
 	g_signal_connect (gtk_settings_get_default (), "notify::gtk-theme-name",
 			  G_CALLBACK (theme_changed), app);
 	theme_changed (gtk_settings_get_default (), NULL, app);
@@ -379,6 +382,10 @@ about_activated (GSimpleAction *action,
 						 "software on your system."));
 
 	gs_shell_modal_dialog_present (app->shell, GTK_DIALOG (dialog));
+
+	/* just destroy */
+	g_signal_connect_swapped (dialog, "response",
+				  G_CALLBACK (gtk_widget_destroy), dialog);
 }
 
 static void
@@ -390,9 +397,6 @@ profile_activated (GSimpleAction *action,
 	as_profile_dump (app->profile);
 }
 
-/**
- * cancel_trigger_failed_cb:
- **/
 static void
 cancel_trigger_failed_cb (GObject *source, GAsyncResult *res, gpointer user_data)
 {
@@ -404,9 +408,6 @@ cancel_trigger_failed_cb (GObject *source, GAsyncResult *res, gpointer user_data
 	}
 }
 
-/**
- * reboot_failed_cb:
- **/
 static void
 reboot_failed_cb (GObject *source, GAsyncResult *res, gpointer user_data)
 {
@@ -433,9 +434,6 @@ reboot_failed_cb (GObject *source, GAsyncResult *res, gpointer user_data)
 					   app);
 }
 
-/**
- * offline_update_cb:
- **/
 static void
 offline_update_cb (GsPluginLoader *plugin_loader,
 		   GAsyncResult *res,
@@ -461,9 +459,6 @@ offline_update_cb (GsPluginLoader *plugin_loader,
 				app);
 }
 
-/**
- * gs_application_reboot_failed_cb:
- **/
 static void
 gs_application_reboot_failed_cb (GObject *source,
 				 GAsyncResult *res,
@@ -854,6 +849,12 @@ gs_application_handle_local_options (GApplication *app, GVariantDict *options)
 						NULL);
 		return 0;
 	}
+	if (g_variant_dict_contains (options, "quit")) {
+		g_action_group_activate_action (G_ACTION_GROUP (app),
+						"quit",
+						NULL);
+		return 0;
+	}
 
 	if (g_variant_dict_lookup (options, "mode", "&s", &mode)) {
 		g_action_group_activate_action (G_ACTION_GROUP (app),
@@ -903,8 +904,14 @@ gs_application_open (GApplication  *application,
 			continue;
 
 		if (g_strcmp0 (soup_uri_get_scheme (uri), "appstream") == 0) {
+			const gchar *host = soup_uri_get_host (uri);
 			const gchar *path = soup_uri_get_path (uri);
 
+			/* appstream://foo -> scheme: appstream, host: foo, path: / */
+			/* appstream:foo -> scheme: appstream, host: (empty string), path: /foo */
+			if (host != NULL && (strlen (host) > 0))
+				path = host;
+
 			/* trim any leading slashes */
 			while (*path == '/')
 				path++;
