@@ -620,7 +620,7 @@ gs_utils_widget_css_parsing_error_cb (GtkCssProvider *provider,
 				      GError *error,
 				      gpointer user_data)
 {
-	g_warning ("CSS parse error %i:%i: %s",
+	g_warning ("CSS parse error %u:%u: %s",
 		   gtk_css_section_get_start_line (section),
 		   gtk_css_section_get_start_position (section),
 		   error->message);
@@ -658,9 +658,16 @@ void
 gs_utils_widget_set_css_simple (GtkWidget *widget, const gchar *css)
 {
 	g_autofree gchar *class_name = NULL;
-	g_autoptr(GString) str = g_string_sized_new (1024);
+	g_autoptr(GString) str = NULL;
 
+	/* remove custom class if NULL */
 	class_name = g_strdup_printf ("themed-widget_%p", widget);
+	if (css == NULL) {
+		GtkStyleContext *context = gtk_widget_get_style_context (widget);
+		gtk_style_context_remove_class (context, class_name);
+		return;
+	}
+	str = g_string_sized_new (1024);
 	g_string_append_printf (str, ".%s {\n", class_name);
 	g_string_append_printf (str, "%s\n", css);
 	g_string_append (str, "}");
@@ -694,7 +701,7 @@ gs_utils_widget_set_css_app (GsApp *app,
 		GdkRGBA *color = g_ptr_array_index (key_colors, 1);
 		g_autofree gchar *key = NULL;
 		g_autofree gchar *value = NULL;
-		key = g_strdup_printf ("@keycolor-%02i@", i);
+		key = g_strdup_printf ("@keycolor-%02u@", i);
 		value = g_strdup_printf ("rgb(%.0f,%.0f,%.0f)",
 					 color->red * 255.f,
 					 color->green * 255.f,
