@@ -604,26 +604,6 @@ gboolean	 gs_plugin_update_app			(GsPlugin	*plugin,
 							 GCancellable	*cancellable,
 							 GError		**error);
 
-/**
- * gs_plugin_add_source:
- * @plugin: a #GsPlugin
- * @app: a #GsApp, with kind %AS_ID_KIND_SOURCE
- * @cancellable: a #GCancellable, or %NULL
- * @error: a #GError, or %NULL
- *
- * Adds a specific source to the system.
- *
- * Adding a source means that applications can be installed from that source,
- * along with any new search results.
- * A new entry is also shown in the "Sources" dialog.
- *
- * Returns: %TRUE for success or if not relevant
- **/
-gboolean	 gs_plugin_add_source			(GsPlugin	*plugin,
-							 GsApp		*app,
-							 GCancellable	*cancellable,
-							 GError		**error);
-
 /**
  * gs_plugin_app_upgrade_download:
  * @plugin: a #GsPlugin
@@ -664,7 +644,7 @@ gboolean	 gs_plugin_app_upgrade_trigger		(GsPlugin	*plugin,
  * gs_plugin_review_submit:
  * @plugin: a #GsPlugin
  * @app: a #GsApp
- * @review: a #GsReview
+ * @review: a #AsReview
  * @cancellable: a #GCancellable, or %NULL
  * @error: a #GError, or %NULL
  *
@@ -674,7 +654,7 @@ gboolean	 gs_plugin_app_upgrade_trigger		(GsPlugin	*plugin,
  **/
 gboolean	 gs_plugin_review_submit		(GsPlugin	*plugin,
 							 GsApp		*app,
-							 GsReview	*review,
+							 AsReview	*review,
 							 GCancellable	*cancellable,
 							 GError		**error);
 
@@ -682,7 +662,7 @@ gboolean	 gs_plugin_review_submit		(GsPlugin	*plugin,
  * gs_plugin_review_upvote:
  * @plugin: a #GsPlugin
  * @app: a #GsApp
- * @review: a #GsReview
+ * @review: a #AsReview
  * @cancellable: a #GCancellable, or %NULL
  * @error: a #GError, or %NULL
  *
@@ -692,7 +672,7 @@ gboolean	 gs_plugin_review_submit		(GsPlugin	*plugin,
  **/
 gboolean	 gs_plugin_review_upvote		(GsPlugin	*plugin,
 							 GsApp		*app,
-							 GsReview	*review,
+							 AsReview	*review,
 							 GCancellable	*cancellable,
 							 GError		**error);
 
@@ -700,7 +680,7 @@ gboolean	 gs_plugin_review_upvote		(GsPlugin	*plugin,
  * gs_plugin_review_downvote:
  * @plugin: a #GsPlugin
  * @app: a #GsApp
- * @review: a #GsReview
+ * @review: a #AsReview
  * @cancellable: a #GCancellable, or %NULL
  * @error: a #GError, or %NULL
  *
@@ -712,7 +692,7 @@ gboolean	 gs_plugin_review_upvote		(GsPlugin	*plugin,
  **/
 gboolean	 gs_plugin_review_downvote		(GsPlugin	*plugin,
 							 GsApp		*app,
-							 GsReview	*review,
+							 AsReview	*review,
 							 GCancellable	*cancellable,
 							 GError		**error);
 
@@ -720,7 +700,7 @@ gboolean	 gs_plugin_review_downvote		(GsPlugin	*plugin,
  * gs_plugin_review_report:
  * @plugin: a #GsPlugin
  * @app: a #GsApp
- * @review: a #GsReview
+ * @review: a #AsReview
  * @cancellable: a #GCancellable, or %NULL
  * @error: a #GError, or %NULL
  *
@@ -732,7 +712,7 @@ gboolean	 gs_plugin_review_downvote		(GsPlugin	*plugin,
  **/
 gboolean	 gs_plugin_review_report		(GsPlugin	*plugin,
 							 GsApp		*app,
-							 GsReview	*review,
+							 AsReview	*review,
 							 GCancellable	*cancellable,
 							 GError		**error);
 
@@ -740,18 +720,18 @@ gboolean	 gs_plugin_review_report		(GsPlugin	*plugin,
  * gs_plugin_review_remove:
  * @plugin: a #GsPlugin
  * @app: a #GsApp
- * @review: a #GsReview
+ * @review: a #AsReview
  * @cancellable: a #GCancellable, or %NULL
  * @error: a #GError, or %NULL
  *
  * Remove a review that the user wrote.
- * NOTE: Users should only be able to remove reviews with %GS_REVIEW_FLAG_SELF.
+ * NOTE: Users should only be able to remove reviews with %AS_REVIEW_FLAG_SELF.
  *
  * Returns: %TRUE for success or if not relevant
  **/
 gboolean	 gs_plugin_review_remove		(GsPlugin	*plugin,
 							 GsApp		*app,
-							 GsReview	*review,
+							 AsReview	*review,
 							 GCancellable	*cancellable,
 							 GError		**error);
 
@@ -759,7 +739,7 @@ gboolean	 gs_plugin_review_remove		(GsPlugin	*plugin,
  * gs_plugin_review_dismiss:
  * @plugin: a #GsPlugin
  * @app: a #GsApp
- * @review: a #GsReview
+ * @review: a #AsReview
  * @cancellable: a #GCancellable, or %NULL
  * @error: a #GError, or %NULL
  *
@@ -771,7 +751,7 @@ gboolean	 gs_plugin_review_remove		(GsPlugin	*plugin,
  **/
 gboolean	 gs_plugin_review_dismiss		(GsPlugin	*plugin,
 							 GsApp		*app,
-							 GsReview	*review,
+							 AsReview	*review,
 							 GCancellable	*cancellable,
 							 GError		**error);
 
