@@ -57,6 +57,16 @@ gs_app_list_filter_cb (GsApp *app, gpointer user_data)
 	return TRUE;
 }
 
+static void
+gs_utils_wilson_func (void)
+{
+	g_assert_cmpint ((gint64) gs_utils_get_wilson_rating (0, 0, 0, 0, 0), ==, -1);
+	g_assert_cmpint ((gint64) gs_utils_get_wilson_rating (0, 0, 0, 0, 400), ==, 100);
+	g_assert_cmpint ((gint64) gs_utils_get_wilson_rating (10, 0, 0, 0, 400), ==, 98);
+	g_assert_cmpint ((gint64) gs_utils_get_wilson_rating (0, 0, 0, 0, 1), ==, 76);
+	g_assert_cmpint ((gint64) gs_utils_get_wilson_rating (5, 4, 20, 100, 400), ==, 93);
+}
+
 static void
 gs_os_release_func (void)
 {
@@ -144,22 +154,39 @@ gs_plugin_func (void)
 
 	/* respect priority when deduplicating */
 	list = gs_app_list_new ();
-	app = gs_app_new ("foo:e");
+	app = gs_app_new ("e");
+	gs_app_set_unique_id (app, "user/foo/*/*/e/*");
 	gs_app_list_add (list, app);
 	gs_app_set_priority (app, 0);
 	g_object_unref (app);
-	app = gs_app_new ("bar:e");
+	app = gs_app_new ("e");
+	gs_app_set_unique_id (app, "user/bar/*/*/e/*");
 	gs_app_list_add (list, app);
 	gs_app_set_priority (app, 99);
 	g_object_unref (app);
-	app = gs_app_new ("baz:e");
+	app = gs_app_new ("e");
+	gs_app_set_unique_id (app, "user/baz/*/*/e/*");
 	gs_app_list_add (list, app);
 	gs_app_set_priority (app, 50);
 	g_object_unref (app);
 	g_assert_cmpint (gs_app_list_length (list), ==, 3);
 	gs_app_list_filter_duplicates (list, GS_APP_LIST_FILTER_FLAG_PRIORITY);
 	g_assert_cmpint (gs_app_list_length (list), ==, 1);
-	g_assert_cmpstr (gs_app_get_id (gs_app_list_index (list, 0)), ==, "bar:e");
+	g_assert_cmpstr (gs_app_get_unique_id (gs_app_list_index (list, 0)), ==, "user/bar/*/*/e/*");
+	g_object_unref (list);
+
+	/* use globs when adding */
+	list = gs_app_list_new ();
+	app = gs_app_new ("b");
+	gs_app_set_unique_id (app, "a/b/c/d/e/f");
+	gs_app_list_add (list, app);
+	g_object_unref (app);
+	app = gs_app_new ("b");
+	gs_app_set_unique_id (app, "a/b/c/*/e/f");
+	gs_app_list_add (list, app);
+	g_object_unref (app);
+	g_assert_cmpint (gs_app_list_length (list), ==, 1);
+	g_assert_cmpstr (gs_app_get_id (gs_app_list_index (list, 0)), ==, "b");
 	g_object_unref (list);
 }
 
@@ -168,11 +195,9 @@ gs_app_func (void)
 {
 	g_autoptr(GsApp) app = NULL;
 
-	app = gs_app_new ("flatpak:gnome-software");
+	app = gs_app_new ("gnome-software.desktop");
 	g_assert (GS_IS_APP (app));
-
-	g_assert_cmpstr (gs_app_get_id (app), ==, "flatpak:gnome-software");
-	g_assert_cmpstr (gs_app_get_id_no_prefix (app), ==, "gnome-software");
+	g_assert_cmpstr (gs_app_get_id (app), ==, "gnome-software.desktop");
 
 	/* check we clean up the version, but not at the expense of having
 	 * the same string as the update version */
@@ -465,7 +490,6 @@ gs_plugin_loader_installed_func (GsPluginLoader *plugin_loader)
 	g_assert (kudos & GS_APP_KUDO_MY_LANGUAGE);
 
 	/* check categories */
-	g_assert (gs_app_has_category (app, "Audio"));
 	g_assert (gs_app_has_category (app, "Player"));
 	g_assert (gs_app_has_category (app, "AudioVideo"));
 	g_assert (!gs_app_has_category (app, "ImageProcessing"));
@@ -518,6 +542,10 @@ gs_plugin_loader_webapps_func (GsPluginLoader *plugin_loader)
 	g_autoptr(GError) error = NULL;
 	g_autoptr(GsApp) app = NULL;
 
+	/* no epiphany, abort */
+	if (!gs_plugin_loader_get_enabled (plugin_loader, "epiphany"))
+		return;
+
 	/* a webapp with a local icon */
 	app = gs_app_new ("arachne.desktop");
 	gs_app_set_kind (app, AS_APP_KIND_WEB_APP);
@@ -632,7 +660,7 @@ gs_plugin_loader_fwupd_func (GsPluginLoader *plugin_loader)
 	g_assert_cmpstr (gs_app_get_name (app), ==, "Chiron");
 	g_assert_cmpstr (gs_app_get_summary (app), ==, "Single line synopsis");
 	g_assert_cmpstr (gs_app_get_version (app), ==, "0.2");
-	g_assert_cmpint (gs_app_get_size_download (app), ==, 32784);
+	g_assert_cmpint ((gint64) gs_app_get_size_download (app), ==, 32784);
 	g_assert_cmpstr (gs_app_get_description (app), ==,
 			 "This is the first paragraph in the example "
 			 "cab file.\n\nThis is the second paragraph.");
@@ -662,6 +690,95 @@ gs_plugin_loader_repos_func (GsPluginLoader *plugin_loader)
 	g_assert_cmpstr (gs_app_get_origin_hostname (app), ==, "people.freedesktop.org");
 }
 
+static void
+gs_plugin_loader_flatpak_repo_func (GsPluginLoader *plugin_loader)
+{
+	const gchar *group_name = "remote \"example\"";
+	const gchar *root = NULL;
+	gboolean ret;
+	g_autofree gchar *config_fn = NULL;
+	g_autofree gchar *fn = NULL;
+	g_autofree gchar *remote_url = NULL;
+	g_autoptr(GError) error = NULL;
+	g_autoptr(GFile) file = NULL;
+	g_autoptr(GKeyFile) kf = NULL;
+	g_autoptr(GsApp) app2 = NULL;
+	g_autoptr(GsApp) app = NULL;
+
+	/* no flatpak, abort */
+	if (!gs_plugin_loader_get_enabled (plugin_loader, "flatpak-user"))
+		return;
+
+	/* load local file */
+	fn = gs_test_get_filename ("tests/example.flatpakrepo");
+	g_assert (fn != NULL);
+	file = g_file_new_for_path (fn);
+	app = gs_plugin_loader_file_to_app (plugin_loader,
+					    file,
+					    GS_PLUGIN_REFINE_FLAGS_DEFAULT,
+					    NULL,
+					    &error);
+	g_assert_no_error (error);
+	g_assert (app != NULL);
+	g_assert_cmpint (gs_app_get_kind (app), ==, AS_APP_KIND_SOURCE);
+	g_assert_cmpint (gs_app_get_state (app), ==, AS_APP_STATE_AVAILABLE);
+	g_assert_cmpstr (gs_app_get_id (app), ==, "example");
+	g_assert_cmpstr (gs_app_get_management_plugin (app), ==, "flatpak-user");
+	g_assert_cmpstr (gs_app_get_origin_hostname(app), ==, "foo.bar");
+	g_assert_cmpstr (gs_app_get_url (app, AS_URL_KIND_HOMEPAGE), ==, "http://foo.bar");
+	g_assert_cmpstr (gs_app_get_name (app), ==, "foo-bar");
+	g_assert_cmpstr (gs_app_get_summary (app), ==, "Longer one line comment");
+	g_assert_cmpstr (gs_app_get_description (app), ==,
+			 "Longer multiline comment that does into detail.");
+	g_assert (gs_app_get_local_file (app) != NULL);
+	g_assert (gs_app_get_pixbuf (app) != NULL);
+
+	/* now install the remote */
+	ret = gs_plugin_loader_app_action (plugin_loader, app,
+					   GS_PLUGIN_LOADER_ACTION_INSTALL,
+					   NULL,
+					   &error);
+	g_assert_no_error (error);
+	g_assert (ret);
+	g_assert_cmpint (gs_app_get_state (app), ==, AS_APP_STATE_INSTALLED);
+
+	/* check config file was updated */
+	root = g_getenv ("GS_SELF_TEST_FLATPACK_DATADIR");
+	config_fn = g_build_filename (root, "flatpak", "repo", "config", NULL);
+	kf = g_key_file_new ();
+	ret = g_key_file_load_from_file (kf, config_fn, 0, &error);
+	g_assert_no_error (error);
+	g_assert (ret);
+
+	g_assert (g_key_file_has_group (kf, "core"));
+	g_assert (g_key_file_has_group (kf, group_name));
+	g_assert (g_key_file_get_boolean (kf, group_name, "gpg-verify", NULL));
+
+	/* check the URL was unmangled */
+	remote_url = g_key_file_get_string (kf, group_name, "url", &error);
+	g_assert_no_error (error);
+	g_assert_cmpstr (remote_url, ==, "http://foo.bar");
+
+	/* try again, check state is correct */
+	app2 = gs_plugin_loader_file_to_app (plugin_loader,
+					     file,
+					     GS_PLUGIN_REFINE_FLAGS_DEFAULT,
+					     NULL,
+					     &error);
+	g_assert_no_error (error);
+	g_assert (app2 != NULL);
+	g_assert_cmpint (gs_app_get_state (app2), ==, AS_APP_STATE_INSTALLED);
+
+	/* remove it */
+	ret = gs_plugin_loader_app_action (plugin_loader, app,
+					   GS_PLUGIN_LOADER_ACTION_REMOVE,
+					   NULL,
+					   &error);
+	g_assert_no_error (error);
+	g_assert (ret);
+	g_assert_cmpint (gs_app_get_state (app), ==, AS_APP_STATE_AVAILABLE);
+}
+
 static void
 gs_plugin_loader_flatpak_func (GsPluginLoader *plugin_loader)
 {
@@ -713,7 +830,7 @@ gs_plugin_loader_flatpak_func (GsPluginLoader *plugin_loader)
 	gs_app_set_state (app_source, AS_APP_STATE_AVAILABLE);
 	gs_app_set_url (app_source, AS_URL_KIND_HOMEPAGE, testdir_repourl);
 	ret = gs_plugin_loader_app_action (plugin_loader, app_source,
-					   GS_PLUGIN_LOADER_ACTION_ADD_SOURCE,
+					   GS_PLUGIN_LOADER_ACTION_INSTALL,
 					   NULL,
 					   &error);
 	g_assert_no_error (error);
@@ -766,9 +883,10 @@ gs_plugin_loader_flatpak_func (GsPluginLoader *plugin_loader)
 	g_assert_cmpstr (gs_app_get_id (app), ==, "org.test.Chiron.desktop");
 	g_assert_cmpint (gs_app_get_kind (app), ==, AS_APP_KIND_DESKTOP);
 	g_assert_cmpint (gs_app_get_state (app), ==, AS_APP_STATE_AVAILABLE);
-	g_assert_cmpint (gs_app_get_kudos (app), ==, GS_APP_KUDO_HAS_KEYWORDS |
-						     GS_APP_KUDO_SANDBOXED_SECURE |
-						     GS_APP_KUDO_SANDBOXED);
+	g_assert_cmpint ((gint64) gs_app_get_kudos (app), ==,
+			 GS_APP_KUDO_HAS_KEYWORDS |
+			 GS_APP_KUDO_SANDBOXED_SECURE |
+			 GS_APP_KUDO_SANDBOXED);
 	g_assert_cmpstr (gs_app_get_origin_hostname (app), ==, "");
 
 	/* install, also installing runtime */
@@ -870,8 +988,8 @@ gs_plugin_loader_authentication_func (GsPluginLoader *plugin_loader)
 	gboolean ret;
 	g_autoptr(GError) error = NULL;
 	g_autoptr(GsApp) app = NULL;
-	g_autoptr(GsReview) review = NULL;
-	g_autoptr(GsReview) review2 = NULL;
+	g_autoptr(AsReview) review = NULL;
+	g_autoptr(AsReview) review2 = NULL;
 
 	/* check initial state */
 	auth = gs_plugin_loader_get_auth_by_id (plugin_loader, "dummy");
@@ -889,9 +1007,9 @@ gs_plugin_loader_authentication_func (GsPluginLoader *plugin_loader)
 
 	/* do an action that requires a login */
 	app = gs_app_new (NULL);
-	review = gs_review_new ();
+	review = as_review_new ();
 	ret = gs_plugin_loader_review_action (plugin_loader, app, review,
-					      GS_REVIEW_ACTION_REMOVE,
+					      GS_PLUGIN_REVIEW_ACTION_REMOVE,
 					      NULL, &error);
 	g_assert_error (error, GS_PLUGIN_ERROR, GS_PLUGIN_ERROR_AUTH_REQUIRED);
 	g_assert (!ret);
@@ -917,9 +1035,9 @@ gs_plugin_loader_authentication_func (GsPluginLoader *plugin_loader)
 	g_assert (gs_auth_has_flag (auth, GS_AUTH_FLAG_VALID));
 
 	/* do the action that requires a login */
-	review2 = gs_review_new ();
+	review2 = as_review_new ();
 	ret = gs_plugin_loader_review_action (plugin_loader, app, review2,
-					      GS_REVIEW_ACTION_REMOVE,
+					      GS_PLUGIN_REVIEW_ACTION_REMOVE,
 					      NULL, &error);
 	g_assert_no_error (error);
 	g_assert (ret);
@@ -1110,6 +1228,7 @@ main (int argc, char **argv)
 	g_log_set_fatal_mask (NULL, G_LOG_LEVEL_ERROR | G_LOG_LEVEL_CRITICAL);
 
 	/* generic tests go here */
+	g_test_add_func ("/gnome-software/utils{wilson}", gs_utils_wilson_func);
 	g_test_add_func ("/gnome-software/os-release", gs_os_release_func);
 	g_test_add_func ("/gnome-software/app", gs_app_func);
 	g_test_add_func ("/gnome-software/plugin", gs_plugin_func);
@@ -1181,6 +1300,12 @@ main (int argc, char **argv)
 	g_test_add_data_func ("/gnome-software/plugin-loader{distro-upgrades}",
 			      plugin_loader,
 			      (GTestDataFunc) gs_plugin_loader_distro_upgrades_func);
+
+	/* done last as it would otherwise try to do downloading in other
+	 * gs_plugin_file_to_app()-using tests */
+	g_test_add_data_func ("/gnome-software/plugin-loader{flatpak:repo}",
+			      plugin_loader,
+			      (GTestDataFunc) gs_plugin_loader_flatpak_repo_func);
 	return g_test_run ();
 }
 
