@@ -419,17 +419,14 @@ gs_shell_details_refresh_progress (GsShellDetails *self)
 	case AS_APP_STATE_INSTALLING:
 		percentage = gs_app_get_progress (self->app);
 		if (percentage > 0) {
-			gtk_widget_set_visible (self->label_progress_percentage, FALSE);
-			gtk_widget_set_visible (self->progressbar_top, FALSE);
-		} else {
-			g_autofree gchar *str = g_strdup_printf ("%i%%", percentage);
+			g_autofree gchar *str = g_strdup_printf ("%u%%", percentage);
 			gtk_label_set_label (GTK_LABEL (self->label_progress_percentage), str);
 			gtk_widget_set_visible (self->label_progress_percentage, TRUE);
 			gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (self->progressbar_top),
 						       (gdouble) percentage / 100.f);
 			gtk_widget_set_visible (self->progressbar_top, TRUE);
+			break;
 		}
-		break;
 	default:
 		gtk_widget_set_visible (self->label_progress_percentage, FALSE);
 		gtk_widget_set_visible (self->progressbar_top, FALSE);
@@ -569,6 +566,7 @@ gs_shell_details_refresh_screenshots (GsShellDetails *self)
 	switch (gs_app_get_kind (self->app)) {
 	case AS_APP_KIND_CODEC:
 	case AS_APP_KIND_ADDON:
+	case AS_APP_KIND_SOURCE:
 		gtk_widget_set_visible (self->box_details_screenshot_fallback, FALSE);
 		break;
 	default:
@@ -681,7 +679,7 @@ gs_shell_details_set_description (GsShellDetails *self, const gchar *tmp)
 	if (gs_app_get_kind (self->app) == AS_APP_KIND_WEB_APP) {
 		GtkWidget *label;
 		/* TRANSLATORS: this is the warning box */
-		label = gtk_label_new ("This application can only be used when there is an active internet connection.");
+		label = gtk_label_new (_("This application can only be used when there is an active internet connection."));
 		gtk_widget_set_visible (label, TRUE);
 		gtk_label_set_xalign (GTK_LABEL (label), 0.f);
 		gtk_style_context_add_class (gtk_widget_get_style_context (label),
@@ -812,27 +810,29 @@ gs_shell_details_refresh_all (GsShellDetails *self)
 	}
 
 	/* set the installed size */
-	if (gs_app_get_size_installed (self->app) == GS_APP_SIZE_UNKNOWABLE) {
-		gtk_widget_hide (self->label_details_size_installed_title);
-		gtk_widget_hide (self->label_details_size_installed_value);
-	} else {
+	if (gs_app_get_size_installed (self->app) != GS_APP_SIZE_UNKNOWABLE &&
+	    gs_app_get_size_installed (self->app) != 0) {
 		g_autofree gchar *size = NULL;
 		size = g_format_size (gs_app_get_size_installed (self->app));
 		gtk_label_set_label (GTK_LABEL (self->label_details_size_installed_value), size);
 		gtk_widget_show (self->label_details_size_installed_title);
 		gtk_widget_show (self->label_details_size_installed_value);
+	} else {
+		gtk_widget_hide (self->label_details_size_installed_title);
+		gtk_widget_hide (self->label_details_size_installed_value);
 	}
 
 	/* set the download size */
-	if (gs_app_get_size_download (self->app) == GS_APP_SIZE_UNKNOWABLE) {
-		gtk_widget_hide (self->label_details_size_download_title);
-		gtk_widget_hide (self->label_details_size_download_value);
-	} else {
+	if (!gs_app_is_installed (self->app) &&
+	    gs_app_get_size_download (self->app) != GS_APP_SIZE_UNKNOWABLE) {
 		g_autofree gchar *size = NULL;
 		size = g_format_size (gs_app_get_size_download (self->app));
 		gtk_label_set_label (GTK_LABEL (self->label_details_size_download_value), size);
 		gtk_widget_show (self->label_details_size_download_title);
 		gtk_widget_show (self->label_details_size_download_value);
+	} else {
+		gtk_widget_hide (self->label_details_size_download_title);
+		gtk_widget_hide (self->label_details_size_download_value);
 	}
 
 	/* set the updated date */
@@ -844,7 +844,7 @@ gs_shell_details_refresh_all (GsShellDetails *self)
 	} else {
 		g_autoptr(GDateTime) dt = NULL;
 		g_autofree gchar *updated_str = NULL;
-		dt = g_date_time_new_from_unix_utc (updated);
+		dt = g_date_time_new_from_unix_utc ((gint64) updated);
 		updated_str = g_date_time_format (dt, "%x");
 
 		history = gs_app_get_history (self->app);
@@ -1066,9 +1066,9 @@ static void gs_shell_details_refresh_reviews (GsShellDetails *self);
 
 typedef struct {
 	GsShellDetails		*self;
-	GsReview		*review;
+	AsReview		*review;
 	GsApp			*app;
-	GsReviewAction		 action;
+	GsPluginReviewAction		 action;
 } GsShellDetailsReviewHelper;
 
 static void
@@ -1147,7 +1147,7 @@ gs_shell_details_app_set_review_cb (GObject *source,
 
 static void
 gs_shell_details_review_button_clicked_cb (GsReviewRow *row,
-					   GsReviewAction action,
+					   GsPluginReviewAction action,
 					   GsShellDetails *self)
 {
 	GsShellDetailsReviewHelper *helper = g_new0 (GsShellDetailsReviewHelper, 1);
@@ -1171,19 +1171,19 @@ gs_shell_details_refresh_reviews (GsShellDetails *self)
 	GPtrArray *reviews;
 	gboolean show_review_button = TRUE;
 	gboolean show_reviews = FALSE;
-	gint n_reviews = 0;
+	guint n_reviews = 0;
 	guint64 possible_actions = 0;
 	guint i;
 	struct {
-		GsReviewAction action;
+		GsPluginReviewAction action;
 		const gchar *plugin_func;
 	} plugin_vfuncs[] = {
-		{ GS_REVIEW_ACTION_UPVOTE,	"gs_plugin_review_upvote" },
-		{ GS_REVIEW_ACTION_DOWNVOTE,	"gs_plugin_review_downvote" },
-		{ GS_REVIEW_ACTION_REPORT,	"gs_plugin_review_report" },
-		{ GS_REVIEW_ACTION_SUBMIT,	"gs_plugin_review_submit" },
-		{ GS_REVIEW_ACTION_REMOVE,	"gs_plugin_review_remove" },
-		{ GS_REVIEW_ACTION_LAST,	NULL }
+		{ GS_PLUGIN_REVIEW_ACTION_UPVOTE,	"gs_plugin_review_upvote" },
+		{ GS_PLUGIN_REVIEW_ACTION_DOWNVOTE,	"gs_plugin_review_downvote" },
+		{ GS_PLUGIN_REVIEW_ACTION_REPORT,	"gs_plugin_review_report" },
+		{ GS_PLUGIN_REVIEW_ACTION_SUBMIT,	"gs_plugin_review_submit" },
+		{ GS_PLUGIN_REVIEW_ACTION_REMOVE,	"gs_plugin_review_remove" },
+		{ GS_PLUGIN_REVIEW_ACTION_LAST,	NULL }
 	};
 
 	/* show or hide the entire reviews section */
@@ -1219,7 +1219,7 @@ gs_shell_details_refresh_reviews (GsShellDetails *self)
 		}
 		if (review_ratings != NULL) {
 			for (i = 0; i < review_ratings->len; i++)
-				n_reviews += g_array_index (review_ratings, gint, i);
+				n_reviews += (guint) g_array_index (review_ratings, gint, i);
 		} else if (gs_app_get_reviews (self->app) != NULL) {
 			n_reviews = gs_app_get_reviews (self->app)->len;
 		}
@@ -1244,10 +1244,10 @@ gs_shell_details_refresh_reviews (GsShellDetails *self)
 		return;
 
 	/* find what the plugins support */
-	for (i = 0; plugin_vfuncs[i].action != GS_REVIEW_ACTION_LAST; i++) {
+	for (i = 0; plugin_vfuncs[i].action != GS_PLUGIN_REVIEW_ACTION_LAST; i++) {
 		if (gs_plugin_loader_get_plugin_supported (self->plugin_loader,
 							   plugin_vfuncs[i].plugin_func)) {
-			possible_actions |= 1 << plugin_vfuncs[i].action;
+			possible_actions |= 1u << plugin_vfuncs[i].action;
 		}
 	}
 
@@ -1259,17 +1259,17 @@ gs_shell_details_refresh_reviews (GsShellDetails *self)
 	gs_container_remove_all (GTK_CONTAINER (self->list_box_reviews));
 	reviews = gs_app_get_reviews (self->app);
 	for (i = 0; i < reviews->len; i++) {
-		GsReview *review = g_ptr_array_index (reviews, i);
+		AsReview *review = g_ptr_array_index (reviews, i);
 		GtkWidget *row = gs_review_row_new (review);
 		guint64 actions;
 
 		g_signal_connect (row, "button-clicked",
 				  G_CALLBACK (gs_shell_details_review_button_clicked_cb), self);
-		if (gs_review_get_flags (review) & GS_REVIEW_FLAG_SELF) {
-			actions = possible_actions & 1 << GS_REVIEW_ACTION_REMOVE;
+		if (as_review_get_flags (review) & AS_REVIEW_FLAG_SELF) {
+			actions = possible_actions & 1 << GS_PLUGIN_REVIEW_ACTION_REMOVE;
 			show_review_button = FALSE;
 		} else {
-			actions = possible_actions & ~(1 << GS_REVIEW_ACTION_REMOVE);
+			actions = possible_actions & ~(1u << GS_PLUGIN_REVIEW_ACTION_REMOVE);
 		}
 		gs_review_row_set_actions (GS_REVIEW_ROW (row), actions);
 		gtk_container_add (GTK_CONTAINER (self->list_box_reviews), row);
@@ -1623,7 +1623,7 @@ gs_shell_details_review_response_cb (GtkDialog *dialog,
 {
 	g_autofree gchar *text = NULL;
 	g_autoptr(GDateTime) now = NULL;
-	g_autoptr(GsReview) review = NULL;
+	g_autoptr(AsReview) review = NULL;
 	GsShellDetailsReviewHelper *helper;
 	GsReviewDialog *rdialog = GS_REVIEW_DIALOG (dialog);
 
@@ -1633,21 +1633,21 @@ gs_shell_details_review_response_cb (GtkDialog *dialog,
 		return;
 	}
 
-	review = gs_review_new ();
-	gs_review_set_summary (review, gs_review_dialog_get_summary (rdialog));
+	review = as_review_new ();
+	as_review_set_summary (review, gs_review_dialog_get_summary (rdialog));
 	text = gs_review_dialog_get_text (rdialog);
-	gs_review_set_text (review, text);
-	gs_review_set_rating (review, gs_review_dialog_get_rating (rdialog));
-	gs_review_set_version (review, gs_app_get_version (self->app));
+	as_review_set_description (review, text);
+	as_review_set_rating (review, gs_review_dialog_get_rating (rdialog));
+	as_review_set_version (review, gs_app_get_version (self->app));
 	now = g_date_time_new_now_local ();
-	gs_review_set_date (review, now);
+	as_review_set_date (review, now);
 
 	/* call into the plugins to set the new value */
 	helper = g_new0 (GsShellDetailsReviewHelper, 1);
 	helper->self = g_object_ref (self);
 	helper->app = g_object_ref (self->app);
 	helper->review = g_object_ref (review);
-	helper->action = GS_REVIEW_ACTION_SUBMIT;
+	helper->action = GS_PLUGIN_REVIEW_ACTION_SUBMIT;
 	gs_plugin_loader_review_action_async (self->plugin_loader,
 					      helper->app,
 					      helper->review,
