@@ -345,8 +345,20 @@ gs_shell_change_mode (GsShell *shell,
 	gs_shell_set_header_end_widget (shell, widget);
 
 	/* destroy any existing modals */
-	if (priv->modal_dialogs != NULL)
+	if (priv->modal_dialogs != NULL) {
+		gsize i = 0;
+		/* block signal emission of 'unmapped' since that will
+		 * call g_ptr_array_remove_index. The unmapped signal may
+		 * be emitted whilst running unref handlers for
+		 * g_ptr_array_set_size */
+		for (i = 0; i < priv->modal_dialogs->len; ++i) {
+			GtkWidget *dialog = g_ptr_array_index (priv->modal_dialogs, i);
+			g_signal_handlers_disconnect_by_func (dialog,
+							      modal_dialog_unmapped_cb,
+							      shell);
+		}
 		g_ptr_array_set_size (priv->modal_dialogs, 0);
+	}
 }
 
 static void
@@ -566,7 +578,7 @@ gs_shell_main_window_mapped_cb (GtkWidget *widget, GsShell *shell)
 {
 	GsShellPrivate *priv = gs_shell_get_instance_private (shell);
 	gs_plugin_loader_set_scale (priv->plugin_loader,
-				    gtk_widget_get_scale_factor (widget));
+				    (guint) gtk_widget_get_scale_factor (widget));
 }
 
 static void
