@@ -47,9 +47,6 @@ G_DEFINE_TYPE_WITH_PRIVATE (GsUpdateList, gs_update_list, GTK_TYPE_LIST_BOX)
 
 #define GET_PRIV(o)	gs_update_list_get_instance_private(o)
 
-/**
- * gs_update_list_button_clicked_cb:
- **/
 static void
 gs_update_list_button_clicked_cb (GsAppRow *app_row,
 				  GsUpdateList *update_list)
@@ -67,6 +64,7 @@ gs_update_list_add_app (GsUpdateList *update_list,
 
 	app_row = gs_app_row_new (app);
 	gs_app_row_set_show_update (GS_APP_ROW (app_row), TRUE);
+	gs_app_row_set_show_buttons (GS_APP_ROW (app_row), TRUE);
 	g_signal_connect (app_row, "button-clicked",
 			  G_CALLBACK (gs_update_list_button_clicked_cb),
 			  update_list);
