@@ -100,20 +100,8 @@ gs_refine_item_icon (GsPlugin *plugin, GsApp *app, AsApp *item)
 
 	/* remote as a last resort */
 	icon = gs_appstream_get_icon_by_kind (item, AS_ICON_KIND_REMOTE);
-	if (icon != NULL) {
-		if (as_icon_get_filename (icon) == NULL) {
-			g_autofree gchar *fn = NULL;
-			g_autofree gchar *cachedir = NULL;
-			fn = gs_utils_get_cache_filename ("icons",
-							  as_icon_get_name (icon),
-							  GS_UTILS_CACHE_FLAG_WRITEABLE,
-							  NULL);
-			as_icon_set_filename (icon, fn);
-			cachedir = g_path_get_basename (fn);
-			as_icon_set_prefix (icon, cachedir);
-		}
+	if (icon != NULL)
 		gs_app_add_icon (app, icon);
-	}
 }
 
 static void
@@ -173,12 +161,29 @@ gs_appstream_refine_add_screenshots (GsApp *app, AsApp *item)
 	}
 }
 
+static void
+gs_appstream_refine_add_reviews (GsApp *app, AsApp *item)
+{
+	AsReview *review;
+	GPtrArray *reviews;
+	guint i;
+
+	/* do we have any to add */
+	if (gs_app_get_reviews(app)->len > 0)
+		return;
+	reviews = as_app_get_reviews (item);
+	for (i = 0; i < reviews->len; i++) {
+		review = g_ptr_array_index (reviews, i);
+		gs_app_add_review (app, review);
+	}
+}
+
 static gboolean
 gs_appstream_is_recent_release (AsApp *app)
 {
 	AsRelease *release;
 	GPtrArray *releases;
-	guint secs;
+	guint64 secs;
 
 	/* get newest release */
 	releases = as_app_get_releases (app);
@@ -187,7 +192,7 @@ gs_appstream_is_recent_release (AsApp *app)
 	release = g_ptr_array_index (releases, 0);
 
 	/* is last build less than one year ago? */
-	secs = (g_get_real_time () / G_USEC_PER_SEC) -
+	secs = ((guint64) g_get_real_time () / G_USEC_PER_SEC) -
 		as_release_get_timestamp (release);
 	return secs / (60 * 60 * 24) < 365;
 }
@@ -254,46 +259,34 @@ gs_appstream_create_runtime (GsPlugin *plugin,
 			     GsApp *parent,
 			     const gchar *runtime)
 {
-	const gchar *id_parent;
+	GsApp *app_cache;
 	g_autofree gchar *id = NULL;
 	g_autofree gchar *source = NULL;
-	g_auto(GStrv) id_split = NULL;
-	g_auto(GStrv) runtime_split = NULL;
+	g_auto(GStrv) split = NULL;
 	g_autoptr(GsApp) app = NULL;
 
 	/* get the name/arch/branch */
-	runtime_split = g_strsplit (runtime, "/", -1);
-	if (g_strv_length (runtime_split) != 3)
+	split = g_strsplit (runtime, "/", -1);
+	if (g_strv_length (split) != 3)
 		return NULL;
 
-	/* find the parent app ID prefix */
-	id_parent = gs_app_get_id (parent);
-	if (id_parent == NULL)
-		return NULL;
-	id_split = g_strsplit (id_parent, ":", 2);
-	if (g_strv_length (id_split) == 2) {
-		id = g_strdup_printf ("%s:%s.runtime",
-				      id_split[0],
-				      runtime_split[0]);
-	} else {
-		id = g_strdup_printf ("%s.runtime", runtime_split[0]);
-	}
-
-	/* search in the cache */
-	app = gs_plugin_cache_lookup (plugin, id);
-	if (app != NULL)
-		return g_steal_pointer (&app);
-
 	/* create the complete GsApp from the single string */
+	id = g_strdup_printf ("%s.runtime", split[0]);
 	app = gs_app_new (id);
 	source = g_strdup_printf ("runtime/%s", runtime);
 	gs_app_add_source (app, source);
+	gs_app_set_bundle_kind (app, AS_BUNDLE_KIND_FLATPAK);
 	gs_app_set_kind (app, AS_APP_KIND_RUNTIME);
-	gs_app_set_version (app, runtime_split[2]);
+	gs_app_set_branch (app, split[2]);
+	gs_app_set_scope (app, gs_app_get_scope (parent));
+
+	/* search in the cache */
+	app_cache = gs_plugin_cache_lookup (plugin, gs_app_get_unique_id (app));
+	if (app_cache != NULL)
+		return g_object_ref (app_cache);
 
 	/* save in the cache */
 	gs_plugin_cache_add (plugin, id, app);
-
 	return g_steal_pointer (&app);
 }
 
@@ -326,7 +319,8 @@ gs_refine_item_management_plugin (GsPlugin *plugin, GsApp *app, AsApp *item)
 				app2 = gs_appstream_create_runtime (plugin, app, runtime);
 				if (app2 != NULL) {
 					g_debug ("runtime for %s is %s",
-						 gs_app_get_id (app), runtime);
+						 gs_app_get_unique_id (app),
+						 runtime);
 					gs_app_set_runtime (app, app2);
 				}
 			}
@@ -362,7 +356,7 @@ gs_appstream_refine_app_updates (GsPlugin *plugin,
 		rel = g_ptr_array_index (releases, i);
 
 		/* is newer than what's installed */
-		g_debug ("installed %s update is %s [%i]",
+		g_debug ("installed %s update is %s [%u]",
 			 gs_app_get_version (app),
 			 as_release_get_version (rel),
 			 as_release_get_state (rel));
@@ -449,6 +443,29 @@ _gs_utils_locale_has_translations (const gchar *locale)
 	return TRUE;
 }
 
+static AsBundleKind
+gs_appstream_get_bundle_kind (AsApp *item)
+{
+	GPtrArray *bundles;
+	GPtrArray *pkgnames;
+
+	/* prefer bundle */
+	bundles = as_app_get_bundles (item);
+	if (bundles->len > 0) {
+		AsBundle *bundle = g_ptr_array_index (bundles, 0);
+		if (as_bundle_get_kind (bundle) != AS_BUNDLE_KIND_UNKNOWN)
+			return as_bundle_get_kind (bundle);
+	}
+
+	/* fallback to packages */
+	pkgnames = as_app_get_pkgnames (item);
+	if (pkgnames->len > 0)
+		return AS_BUNDLE_KIND_PACKAGE;
+
+	/* nothing */
+	return AS_BUNDLE_KIND_UNKNOWN;
+}
+
 gboolean
 gs_appstream_refine_app (GsPlugin *plugin,
 			 GsApp *app,
@@ -509,16 +526,19 @@ gs_appstream_refine_app (GsPlugin *plugin,
 	/* set source */
 	gs_app_set_metadata (app, "appstream::source-file", as_app_get_source_file (item));
 
+	/* scope */
+	if (gs_app_get_scope (app) == AS_APP_SCOPE_UNKNOWN &&
+	    as_app_get_scope (item) != AS_APP_SCOPE_UNKNOWN)
+		gs_app_set_scope (app, as_app_get_scope (item));
+
+	/* bundle-kind */
+	if (gs_app_get_bundle_kind (app) == AS_BUNDLE_KIND_UNKNOWN)
+		gs_app_set_bundle_kind (app, gs_appstream_get_bundle_kind (item));
+
 	/* set name */
 	tmp = as_app_get_name (item, NULL);
-	if (tmp != NULL) {
-		if (g_str_has_prefix (tmp, "(Nightly) ")) {
-			tmp += 10;
-			if (gs_app_get_metadata_item (app, "X-XdgApp-Tags") == NULL)
-				gs_app_set_metadata (app, "X-XdgApp-Tags", "nightly");
-		}
+	if (tmp != NULL)
 		gs_app_set_name (app, GS_APP_QUALITY_HIGHEST, tmp);
-	}
 
 	/* set summary */
 	tmp = as_app_get_comment (item, NULL);
@@ -556,11 +576,10 @@ gs_appstream_refine_app (GsPlugin *plugin,
 	/* set origin */
 	if (as_app_get_origin (item) != NULL &&
 	    gs_app_get_origin (app) == NULL ) {
-		tmp = as_app_get_origin (item);
-		if (g_str_has_prefix (tmp, "flatpak:"))
-			gs_app_set_origin (app, tmp + 8);
-		if (g_str_has_prefix (tmp, "user-flatpak:"))
-			gs_app_set_origin (app, tmp + 13);
+		tmp = as_app_get_unique_id (item);
+		if (g_str_has_prefix (tmp, "user/flatpak/") ||
+		    g_str_has_prefix (tmp, "system/flatpak/"))
+			gs_app_set_origin (app, as_app_get_origin (item));
 	}
 
 	/* set description */
@@ -613,6 +632,9 @@ gs_appstream_refine_app (GsPlugin *plugin,
 	/* set screenshots */
 	gs_appstream_refine_add_screenshots (app, item);
 
+	/* set reviews */
+	gs_appstream_refine_add_reviews (app, item);
+
 	/* are the screenshots perfect */
 	if (gs_appstream_are_screenshots_perfect (item))
 		gs_app_add_kudo (app, GS_APP_KUDO_PERFECT_SCREENSHOTS);
