@@ -164,13 +164,13 @@ gs_flatpak_refresh_appstream (GsFlatpak *self, guint cache_age,
 		tmp = gs_utils_get_file_age (file_timestamp);
 		if (tmp < cache_age) {
 			g_autofree gchar *fn = g_file_get_path (file_timestamp);
-			g_debug ("%s is only %i seconds old, so ignoring refresh",
+			g_debug ("%s is only %u seconds old, so ignoring refresh",
 				 fn, tmp);
 			continue;
 		}
 
 		/* download new data */
-		g_debug ("%s is %i seconds old, so downloading new data",
+		g_debug ("%s is %u seconds old, so downloading new data",
 			 remote_name, tmp);
 		ret = flatpak_installation_update_appstream_sync (self->installation,
 								  remote_name,
@@ -229,15 +229,26 @@ gs_app_set_flatpak_kind (GsApp *app, FlatpakRefKind kind)
 		g_assert_not_reached ();
 }
 
+static void
+gs_plugin_refine_item_scope (GsFlatpak *self, GsApp *app)
+{
+	if (gs_app_get_scope (app) == AS_APP_SCOPE_UNKNOWN) {
+		gboolean is_user = flatpak_installation_get_is_user (self->installation);
+		gs_app_set_scope (app, is_user ? AS_APP_SCOPE_USER : AS_APP_SCOPE_SYSTEM);
+	}
+}
+
 static void
 gs_flatpak_set_metadata (GsFlatpak *self, GsApp *app, FlatpakRef *xref)
 {
+	gs_app_set_bundle_kind (app, AS_BUNDLE_KIND_FLATPAK);
 	gs_app_set_management_plugin (app, gs_plugin_get_name (self->plugin));
 	gs_app_set_flatpak_kind (app, flatpak_ref_get_kind (xref));
 	gs_app_set_flatpak_name (app, flatpak_ref_get_name (xref));
 	gs_app_set_flatpak_arch (app, flatpak_ref_get_arch (xref));
 	gs_app_set_flatpak_branch (app, flatpak_ref_get_branch (xref));
 	gs_app_set_flatpak_commit (app, flatpak_ref_get_commit (xref));
+	gs_plugin_refine_item_scope (self, app);
 }
 
 static void
@@ -274,7 +285,8 @@ gs_flatpak_set_metadata_installed (GsFlatpak *self, GsApp *app,
 	}
 
 	/* this is faster than resolving */
-	gs_app_set_origin (app, flatpak_installed_ref_get_origin (xref));
+	if (gs_app_get_origin (app) == NULL)
+		gs_app_set_origin (app, flatpak_installed_ref_get_origin (xref));
 
 	/* this is faster than flatpak_installation_fetch_remote_size_sync() */
 	size_installed = flatpak_installed_ref_get_installed_size (xref);
@@ -283,23 +295,35 @@ gs_flatpak_set_metadata_installed (GsFlatpak *self, GsApp *app,
 }
 
 static gchar *
-gs_flatpak_build_id (FlatpakInstallation *installation, FlatpakRef *xref)
+gs_flatpak_build_id (FlatpakRef *xref)
 {
-	const gchar *prefix = GS_FLATPAK_SYSTEM_PREFIX;
+	if (flatpak_ref_get_kind (xref) == FLATPAK_REF_KIND_APP) {
+		return g_strdup_printf ("%s.desktop",
+					flatpak_ref_get_name (xref));
+	}
+	return g_strdup_printf ("%s.runtime",
+				flatpak_ref_get_name (xref));
+}
+
+static gchar *
+gs_flatpak_build_unique_id (FlatpakInstallation *installation, FlatpakRef *xref)
+{
+	AsAppKind kind = AS_APP_KIND_DESKTOP;
+	AsAppScope scope = AS_APP_SCOPE_SYSTEM;
+	g_autofree gchar *id = NULL;
 
 	/* use a different prefix if we're somehow running this as per-user */
 	if (flatpak_installation_get_is_user (installation))
-		prefix = GS_FLATPAK_USER_PREFIX;
-
-	/* flatpak doesn't use a suffix; AppStream does */
-	if (flatpak_ref_get_kind (xref) == FLATPAK_REF_KIND_APP) {
-		return g_strdup_printf ("%s:%s.desktop",
-					prefix,
-					flatpak_ref_get_name (xref));
-	}
-	return g_strdup_printf ("%s:%s.runtime",
-				prefix,
-				flatpak_ref_get_name (xref));
+		scope = AS_APP_SCOPE_USER;
+	if (flatpak_ref_get_kind (xref) == FLATPAK_REF_KIND_RUNTIME)
+		kind = AS_APP_KIND_RUNTIME;
+	id = gs_flatpak_build_id (xref);
+	return as_utils_unique_id_build (scope,
+					 AS_BUNDLE_KIND_FLATPAK,
+					 NULL,	/* origin */
+					 kind,
+					 id,
+					 flatpak_ref_get_branch (xref));
 }
 
 static GsApp *
@@ -307,7 +331,7 @@ gs_flatpak_create_installed (GsFlatpak *self,
 			     FlatpakInstalledRef *xref,
 			     GError **error)
 {
-	g_autofree gchar *id = NULL;
+	g_autofree gchar *unique_id = NULL;
 	g_autoptr(AsIcon) icon = NULL;
 	g_autoptr(GsApp) app = NULL;
 
@@ -332,11 +356,13 @@ gs_flatpak_create_installed (GsFlatpak *self,
 	}
 
 	/* create new object */
-	id = gs_flatpak_build_id (self->installation, FLATPAK_REF (xref));
-	app = gs_plugin_cache_lookup (self->plugin, id);
+	unique_id = gs_flatpak_build_unique_id (self->installation,
+						FLATPAK_REF (xref));
+	app = gs_plugin_cache_lookup (self->plugin, unique_id);
 	if (app == NULL) {
+		g_autofree gchar *id = gs_flatpak_build_id (FLATPAK_REF (xref));
 		app = gs_app_new (id);
-		gs_plugin_cache_add (self->plugin, id, app);
+		gs_plugin_cache_add (self->plugin, unique_id, app);
 	}
 	gs_flatpak_set_metadata_installed (self, app, xref);
 
@@ -453,6 +479,7 @@ gs_flatpak_add_sources (GsFlatpak *self, GsAppList *list,
 		gs_app_set_management_plugin (app, gs_plugin_get_name (self->plugin));
 		gs_app_set_kind (app, AS_APP_KIND_SOURCE);
 		gs_app_set_state (app, AS_APP_STATE_INSTALLED);
+		gs_app_add_quirk (app, AS_APP_QUIRK_NOT_LAUNCHABLE);
 		gs_app_set_name (app,
 				 GS_APP_QUALITY_LOWEST,
 				 flatpak_remote_get_name (xremote));
@@ -495,10 +522,10 @@ gs_flatpak_add_sources (GsFlatpak *self, GsAppList *list,
 	return TRUE;
 }
 
-gboolean
-gs_flatpak_add_source (GsFlatpak *self, GsApp *app,
-		       GCancellable *cancellable,
-		       GError **error)
+static gboolean
+gs_flatpak_app_install_source (GsFlatpak *self, GsApp *app,
+			       GCancellable *cancellable,
+			       GError **error)
 {
 	const gchar *gpg_key;
 	g_autoptr(FlatpakRemote) xremote = NULL;
@@ -508,8 +535,22 @@ gs_flatpak_add_source (GsFlatpak *self, GsApp *app,
 		       gs_plugin_get_name (self->plugin)) != 0)
 		return TRUE;
 
+	/* does the remote already exist and is disabled */
+	xremote = flatpak_installation_get_remote_by_name (self->installation,
+							   gs_app_get_id (app),
+							   cancellable, NULL);
+	if (xremote != NULL) {
+		g_set_error (error,
+			     GS_PLUGIN_ERROR,
+			     GS_PLUGIN_ERROR_FAILED,
+			     "flatpak source %s already exists",
+			     flatpak_remote_get_name (xremote));
+		return FALSE;
+	}
+
 	/* create a new remote */
 	xremote = flatpak_remote_new (gs_app_get_id (app));
+	flatpak_remote_set_noenumerate (xremote, FALSE);
 	flatpak_remote_set_url (xremote, gs_app_get_url (app, AS_URL_KIND_HOMEPAGE));
 	if (gs_app_get_summary (app) != NULL)
 		flatpak_remote_set_title (xremote, gs_app_get_summary (app));
@@ -732,6 +773,7 @@ gs_plugin_refine_item_origin_hostname (GsFlatpak *self, GsApp *app,
 			     GS_PLUGIN_ERROR_FAILED,
 			     "no URL for remote %s",
 			     flatpak_remote_get_name (xremote));
+		return FALSE;
 	}
 	gs_app_set_origin_hostname (app, url);
 	return TRUE;
@@ -838,6 +880,17 @@ refine_origin_from_installation (GsFlatpak *self,
 	return FALSE;
 }
 
+static FlatpakInstallation *
+gs_flatpak_get_installation_counterpart (GsFlatpak *self,
+					 GCancellable *cancellable,
+					 GError **error)
+{
+	if (flatpak_installation_get_is_user (self->installation))
+		return flatpak_installation_new_system (cancellable, error);
+
+	return flatpak_installation_new_user (cancellable, error);
+}
+
 static gboolean
 gs_plugin_refine_item_origin (GsFlatpak *self,
 			      GsApp *app,
@@ -876,12 +929,12 @@ gs_plugin_refine_item_origin (GsFlatpak *self,
 
 	/* check the system installation if we're on a user one */
 	if (ignore_error &&
-	    flatpak_installation_get_is_user (self->installation) &&
 	    gs_app_get_flatpak_kind (app) == FLATPAK_REF_KIND_RUNTIME) {
-		g_autoptr(FlatpakInstallation) installation = NULL;
+		g_autoptr(FlatpakInstallation) installation =
+			gs_flatpak_get_installation_counterpart (self,
+								 cancellable,
+								 error);
 
-		installation = flatpak_installation_new_system (cancellable,
-								error);
 		if (installation == NULL)
 			return FALSE;
 
@@ -904,8 +957,8 @@ gs_flatpak_app_matches_xref (GsFlatpak *self, GsApp *app, FlatpakRef *xref)
 	g_autofree gchar *id = NULL;
 
 	/* check ID */
-	id = gs_flatpak_build_id (self->installation, xref);
-	if (g_strcmp0 (id, gs_app_get_id (app)) == 0)
+	id = gs_flatpak_build_unique_id (self->installation, xref);
+	if (g_strcmp0 (id, gs_app_get_unique_id (app)) == 0)
 		return TRUE;
 
 	/* do all the metadata items match? */
@@ -979,13 +1032,13 @@ gs_plugin_refine_item_state (GsFlatpak *self,
 		return FALSE;
 
 	/* special case: if this is per-user instance and the runtime is
-	 * available system-wide then mark it installed */
-	if (flatpak_installation_get_is_user (self->installation) &&
-	    gs_app_get_flatpak_kind (app) == FLATPAK_REF_KIND_RUNTIME &&
+	 * available system-wide then mark it installed, and vice-versa */
+	if (gs_app_get_flatpak_kind (app) == FLATPAK_REF_KIND_RUNTIME &&
 	    gs_app_get_state (app) == AS_APP_STATE_UNKNOWN) {
-		g_autoptr(FlatpakInstallation) installation = NULL;
-		installation = flatpak_installation_new_system (cancellable,
-								error);
+		g_autoptr(FlatpakInstallation) installation =
+			gs_flatpak_get_installation_counterpart (self,
+								 cancellable,
+								 error);
 		if (installation == NULL)
 			return FALSE;
 		xrefs = flatpak_installation_list_installed_refs (installation,
@@ -1020,9 +1073,11 @@ gs_plugin_refine_item_state (GsFlatpak *self,
 				gs_app_set_state (app, AS_APP_STATE_AVAILABLE);
 			}
 		} else {
-			g_warning ("failed to find flatpak user remote %s for %s",
+			g_warning ("failed to find flatpak %s remote %s for %s",
+				   flatpak_installation_get_is_user (self->installation) ? "user" : "system",
 				   gs_app_get_origin (app),
-				   gs_app_get_id (app));
+				   gs_app_get_unique_id (app));
+			g_warning ("%s", gs_app_to_string (app));
 		}
 	}
 
@@ -1087,8 +1142,10 @@ gs_flatpak_set_app_metadata (GsFlatpak *self,
 	/* create runtime */
 	if (gs_app_get_runtime (app) == NULL) {
 		app_runtime = gs_appstream_create_runtime (self->plugin, app, runtime);
-		if (app_runtime != NULL)
+		if (app_runtime != NULL) {
+			gs_plugin_refine_item_scope (self, app_runtime);
 			gs_app_set_runtime (app, app_runtime);
+		}
 	}
 
 	return TRUE;
@@ -1101,7 +1158,7 @@ gs_plugin_refine_item_metadata (GsFlatpak *self,
 			       GError **error)
 {
 	const gchar *str;
-	gsize len = -1;
+	gsize len = 0;
 	g_autofree gchar *contents = NULL;
 	g_autofree gchar *installation_path_str = NULL;
 	g_autofree gchar *install_path = NULL;
@@ -1150,6 +1207,23 @@ gs_plugin_refine_item_metadata (GsFlatpak *self,
 	return TRUE;
 }
 
+static FlatpakInstalledRef *
+gs_flatpak_get_installed_ref (GsFlatpak *self,
+			      GsApp *app,
+			      GCancellable *cancellable,
+			      GError **error)
+{
+	FlatpakInstalledRef *ref;
+	ref = flatpak_installation_get_installed_ref (self->installation,
+						      gs_app_get_flatpak_kind (app),
+						      gs_app_get_flatpak_name (app),
+						      gs_app_get_flatpak_arch (app),
+						      gs_app_get_flatpak_branch (app),
+						      cancellable,
+						      error);
+	return ref;
+}
+
 static gboolean
 gs_plugin_refine_item_size (GsFlatpak *self,
 			    GsApp *app,
@@ -1157,16 +1231,20 @@ gs_plugin_refine_item_size (GsFlatpak *self,
 			    GError **error)
 {
 	gboolean ret;
-	guint64 download_size;
-	guint64 installed_size;
+	guint64 download_size = GS_APP_SIZE_UNKNOWABLE;
+	guint64 installed_size = GS_APP_SIZE_UNKNOWABLE;
 	g_autoptr(AsProfileTask) ptask = NULL;
-	g_autoptr(FlatpakRef) xref = NULL;
-	g_autoptr(GError) error_local = NULL;
 
 	/* already set */
-	if (gs_app_get_size_installed (app) > 0 &&
-	    gs_app_get_size_download (app) > 0)
+	if (gs_app_is_installed (app)) {
+		/* only care about the installed size if the app is installed */
+		if (gs_app_get_size_installed (app) > 0)
+			return TRUE;
+	} else {
+		if (gs_app_get_size_installed (app) > 0 &&
+		    gs_app_get_size_download (app) > 0)
 		return TRUE;
+	}
 
 	/* need runtime */
 	if (!gs_plugin_refine_item_metadata (self, app, cancellable, error))
@@ -1203,24 +1281,39 @@ gs_plugin_refine_item_size (GsFlatpak *self,
 	if (!gs_plugin_refine_item_origin (self, app,
 					   cancellable, error))
 		return FALSE;
-	xref = gs_flatpak_create_fake_ref (app, error);
-	if (xref == NULL)
-		return FALSE;
-	ret = flatpak_installation_fetch_remote_size_sync (self->installation,
-							   gs_app_get_origin (app),
-							   xref,
-							   &download_size,
-							   &installed_size,
-							   cancellable, &error_local);
-	if (!ret) {
-		g_warning ("libflatpak failed to return application size: %s",
-			   error_local->message);
-		gs_app_set_size_installed (app, GS_APP_SIZE_UNKNOWABLE);
-		gs_app_set_size_download (app, GS_APP_SIZE_UNKNOWABLE);
+
+	/* if the app is installed we use the ref to fetch the installed size
+	 * and ignore the download size as this is faster */
+	if (gs_app_is_installed (app)) {
+		g_autoptr(FlatpakInstalledRef) xref = NULL;
+		xref = gs_flatpak_get_installed_ref (self, app,
+						     cancellable, error);
+		installed_size = flatpak_installed_ref_get_installed_size (xref);
+		if (installed_size == 0)
+			installed_size = GS_APP_SIZE_UNKNOWABLE;
 	} else {
-		gs_app_set_size_installed (app, installed_size);
-		gs_app_set_size_download (app, download_size);
+		g_autoptr(FlatpakRef) xref = NULL;
+		g_autoptr(GError) error_local = NULL;
+		xref = gs_flatpak_create_fake_ref (app, error);
+		if (xref == NULL)
+			return FALSE;
+		ret = flatpak_installation_fetch_remote_size_sync (self->installation,
+								   gs_app_get_origin (app),
+								   xref,
+								   &download_size,
+								   &installed_size,
+								   cancellable,
+								   &error_local);
+
+		if (!ret) {
+			g_warning ("libflatpak failed to return application "
+				   "size: %s", error_local->message);
+		}
 	}
+
+	gs_app_set_size_installed (app, installed_size);
+	gs_app_set_size_download (app, download_size);
+
 	return TRUE;
 }
 
@@ -1247,13 +1340,20 @@ gs_flatpak_refine_app (GsFlatpak *self,
 	/* flatpak apps can always be removed */
 	gs_app_remove_quirk (app, AS_APP_QUIRK_COMPULSORY);
 
+	/* scope is fast, do unconditionally */
+	gs_plugin_refine_item_scope (self, app);
+
 	/* AppStream sets the source to appname/arch/branch */
-	if (!gs_refine_item_metadata (self, app, cancellable, error))
+	if (!gs_refine_item_metadata (self, app, cancellable, error)) {
+		g_prefix_error (error, "failed to get metadata: ");
 		return FALSE;
+	}
 
 	/* check the installed state */
-	if (!gs_plugin_refine_item_state (self, app, cancellable, error))
+	if (!gs_plugin_refine_item_state (self, app, cancellable, error)) {
+		g_prefix_error (error, "failed to get state: ");
 		return FALSE;
+	}
 
 	/* version fallback */
 	if (flags & GS_PLUGIN_REFINE_FLAGS_REQUIRE_VERSION) {
@@ -1267,30 +1367,38 @@ gs_flatpak_refine_app (GsFlatpak *self,
 	/* size */
 	if (flags & GS_PLUGIN_REFINE_FLAGS_REQUIRE_SIZE) {
 		if (!gs_plugin_refine_item_size (self, app,
-						 cancellable, error))
-			return FALSE;
-	}
-
-	/* permissions */
-	if (flags & GS_PLUGIN_REFINE_FLAGS_REQUIRE_PERMISSIONS) {
-		if (!gs_plugin_refine_item_metadata (self, app,
-						     cancellable, error))
+						 cancellable, error)) {
+			g_prefix_error (error, "failed to get size: ");
 			return FALSE;
+		}
 	}
 
 	/* origin */
 	if (flags & GS_PLUGIN_REFINE_FLAGS_REQUIRE_ORIGIN) {
 		if (!gs_plugin_refine_item_origin_ui (self, app,
-						      cancellable, error))
+						      cancellable, error)) {
+			g_prefix_error (error, "failed to get origin: ");
 			return FALSE;
+		}
 	}
 
 	/* origin-hostname */
 	if (flags & GS_PLUGIN_REFINE_FLAGS_REQUIRE_ORIGIN_HOSTNAME) {
 		if (!gs_plugin_refine_item_origin_hostname (self, app,
 							    cancellable,
-							    error))
+							    error)) {
+			g_prefix_error (error, "failed to get origin-hostname: ");
 			return FALSE;
+		}
+	}
+
+	/* permissions */
+	if (flags & GS_PLUGIN_REFINE_FLAGS_REQUIRE_PERMISSIONS) {
+		if (!gs_plugin_refine_item_metadata (self, app,
+						     cancellable, error)) {
+			g_prefix_error (error, "failed to get permissions: ");
+			return FALSE;
+		}
 	}
 
 	return TRUE;
@@ -1321,6 +1429,38 @@ gs_flatpak_launch (GsFlatpak *self,
 					    error);
 }
 
+static gboolean
+gs_flatpak_app_remove_source (GsFlatpak *self,
+			      GsApp *app,
+			      GCancellable *cancellable,
+			      GError **error)
+{
+	g_autoptr(FlatpakRemote) xremote = NULL;
+
+	/* find the remote */
+	xremote = flatpak_installation_get_remote_by_name (self->installation,
+							   gs_app_get_id (app),
+							   cancellable, error);
+	if (xremote == NULL) {
+		g_prefix_error (error,
+				"flatpak source %s not found: ",
+				gs_app_get_id (app));
+		return FALSE;
+	}
+
+	/* remove */
+	gs_app_set_state (app, AS_APP_STATE_REMOVING);
+	if (!flatpak_installation_remove_remote (self->installation,
+						 gs_app_get_id (app),
+						 cancellable,
+						 error)) {
+		gs_app_set_state_recover (app);
+		return FALSE;
+	}
+	gs_app_set_state (app, AS_APP_STATE_AVAILABLE);
+	return TRUE;
+}
+
 gboolean
 gs_flatpak_app_remove (GsFlatpak *self,
 		       GsApp *app,
@@ -1338,6 +1478,14 @@ gs_flatpak_app_remove (GsFlatpak *self,
 				    cancellable, error))
 		return FALSE;
 
+	/* is a source */
+	if (gs_app_get_kind (app) == AS_APP_KIND_SOURCE) {
+		return gs_flatpak_app_remove_source (self,
+						     app,
+						     cancellable,
+						     error);
+	}
+
 	/* remove */
 	gs_app_set_state (app, AS_APP_STATE_REMOVING);
 	if (!flatpak_installation_uninstall (self->installation,
@@ -1383,6 +1531,14 @@ gs_flatpak_app_install (GsFlatpak *self,
 	/* install */
 	gs_app_set_state (app, AS_APP_STATE_INSTALLING);
 
+	/* add a source */
+	if (gs_app_get_kind (app) == AS_APP_KIND_SOURCE) {
+		return gs_flatpak_app_install_source (self,
+						      app,
+						      cancellable,
+						      error);
+	}
+
 	/* install required runtime if not already installed */
 	if (gs_app_get_kind (app) == AS_APP_KIND_DESKTOP) {
 		GsApp *runtime;
@@ -1487,6 +1643,9 @@ gs_flatpak_update_app (GsFlatpak *self,
 		return FALSE;
 	}
 
+	/* update UI */
+	gs_plugin_updates_changed (self->plugin);
+
 	/* state is known */
 	gs_app_set_state (app, AS_APP_STATE_INSTALLED);
 	return TRUE;
@@ -1499,8 +1658,9 @@ gs_flatpak_file_to_app_bundle (GsFlatpak *self,
 			       GCancellable *cancellable,
 			       GError **error)
 {
+	gint size;
 	g_autofree gchar *content_type = NULL;
-	g_autofree gchar *id_prefixed = NULL;
+	g_autofree gchar *unique_id = NULL;
 	g_autoptr(GBytes) appstream_gz = NULL;
 	g_autoptr(GBytes) icon_data = NULL;
 	g_autoptr(GBytes) metadata = NULL;
@@ -1515,11 +1675,16 @@ gs_flatpak_file_to_app_bundle (GsFlatpak *self,
 	}
 
 	/* create a virtual ID */
-	id_prefixed = gs_flatpak_build_id (self->installation,
-					   FLATPAK_REF (xref_bundle));
+	unique_id = gs_flatpak_build_unique_id (self->installation,
+						FLATPAK_REF (xref_bundle));
+	app = gs_plugin_cache_lookup (self->plugin, unique_id);
+	if (app == NULL) {
+		g_autofree gchar *id = gs_flatpak_build_id (FLATPAK_REF (xref_bundle));
+		app = gs_app_new (id);
+		gs_plugin_cache_add (self->plugin, unique_id, app);
+	}
 
 	/* load metadata */
-	app = gs_app_new (id_prefixed);
 	gs_app_set_kind (app, AS_APP_KIND_DESKTOP);
 	gs_app_set_state (app, AS_APP_STATE_AVAILABLE_LOCAL);
 	gs_app_set_size_installed (app, flatpak_bundle_ref_get_installed_size (xref_bundle));
@@ -1577,7 +1742,7 @@ gs_flatpak_file_to_app_bundle (GsFlatpak *self,
 					     "no apps found in AppStream data");
 			return FALSE;
 		}
-		g_debug ("%i applications found in AppStream data",
+		g_debug ("%u applications found in AppStream data",
 			 as_store_get_size (store));
 
 		/* find app */
@@ -1598,8 +1763,8 @@ gs_flatpak_file_to_app_bundle (GsFlatpak *self,
 	}
 
 	/* load icon */
-	icon_data = flatpak_bundle_ref_get_icon (xref_bundle,
-						 64 * gs_plugin_get_scale (self->plugin));
+	size = 64 * (gint) gs_plugin_get_scale (self->plugin);
+	icon_data = flatpak_bundle_ref_get_icon (xref_bundle, size);
 	if (icon_data == NULL)
 		icon_data = flatpak_bundle_ref_get_icon (xref_bundle, 64);
 	if (icon_data != NULL) {
@@ -1622,7 +1787,7 @@ gs_flatpak_file_to_app_bundle (GsFlatpak *self,
 	if (flatpak_bundle_ref_get_origin (xref_bundle))
 		gs_app_add_quirk (app, AS_APP_QUIRK_HAS_SOURCE);
 
-	g_debug ("created local app: %s", gs_app_to_string (app));
+	/* success */
 	gs_app_list_add (list, app);
 	return TRUE;
 }
@@ -1676,14 +1841,31 @@ gs_flatpak_file_to_app_repo (GsFlatpak *self,
 	if (repo_title == NULL || repo_url == NULL || repo_gpgkey == NULL ||
 	    repo_title[0] == '\0' || repo_url[0] == '\0' || repo_gpgkey[0] == '\0') {
 		g_set_error_literal (error,
-			     GS_PLUGIN_ERROR,
-			     GS_PLUGIN_ERROR_NOT_SUPPORTED,
-			     "not enough data in file, expected Title, Url, GPGKey");
+				     GS_PLUGIN_ERROR,
+				     GS_PLUGIN_ERROR_NOT_SUPPORTED,
+				     "not enough data in file, "
+				     "expected Title, Url, GPGKey");
 		return FALSE;
 	}
+
+	/* user specified a URL */
+	if (g_str_has_prefix (repo_gpgkey, "http://") ||
+	    g_str_has_prefix (repo_gpgkey, "https://")) {
+		g_set_error_literal (error,
+				     GS_PLUGIN_ERROR,
+				     GS_PLUGIN_ERROR_NOT_SUPPORTED,
+				     "Base64 encoded GPGKey required, not URL");
+		return FALSE;
+	}
+
+	/* create source */
 	app = gs_app_new (repo_id);
+	gs_app_set_kind (app, AS_APP_KIND_SOURCE);
+	gs_app_add_quirk (app, AS_APP_QUIRK_NOT_LAUNCHABLE);
 	gs_app_set_name (app, GS_APP_QUALITY_NORMAL, repo_title);
 	gs_app_set_metadata (app, "flatpak::gpg-key", repo_gpgkey);
+	gs_app_set_origin_hostname (app, repo_url);
+	gs_app_set_management_plugin (app, gs_plugin_get_name (self->plugin));
 
 	/* optional data */
 	repo_homepage = g_key_file_get_string (kf, "Flatpak Repo", "Homepage", NULL);
@@ -1713,6 +1895,9 @@ gs_flatpak_file_to_app_repo (GsFlatpak *self,
 	} else {
 		gs_app_set_state (app, AS_APP_STATE_AVAILABLE);
 	}
+
+	/* success */
+	gs_app_list_add (list, app);
 	return TRUE;
 }
 
