@@ -113,7 +113,7 @@ gs_plugin_detect_reload_apps (GsPlugin *plugin)
 
 	/* invalidate all if a large number of apps changed */
 	if (cnt > GS_PLUGIN_NUMBER_CHANGED_RELOAD) {
-		g_debug ("%i is more than %i AsApps changed",
+		g_debug ("%u is more than %i AsApps changed",
 			 cnt, GS_PLUGIN_NUMBER_CHANGED_RELOAD);
 		gs_plugin_reload (plugin);
 	}
@@ -137,6 +137,9 @@ gs_plugin_initialize (GsPlugin *plugin)
 {
 	GsPluginData *priv = gs_plugin_alloc_data (plugin, sizeof(GsPluginData));
 	priv->store = as_store_new ();
+	as_store_set_add_flags (priv->store,
+				AS_STORE_ADD_FLAG_USE_UNIQUE_ID |
+				AS_STORE_ADD_FLAG_USE_MERGE_HEURISTIC);
 	as_store_set_watch_flags (priv->store,
 				  AS_STORE_WATCH_FLAG_ADDED |
 				  AS_STORE_WATCH_FLAG_REMOVED);
@@ -193,8 +196,8 @@ gs_plugin_appstream_get_origins_hash (GPtrArray *array)
 			continue;
 		cnt = g_hash_table_lookup (origins, tmp);
 		perc = (100.f / (gdouble) array->len) * (gdouble) (*cnt);
-		g_debug ("origin %s provides %i apps (%.0f%%)", tmp, *cnt, perc);
-		*cnt = perc;
+		g_debug ("origin %s provides %u apps (%.0f%%)", tmp, *cnt, perc);
+		*cnt = (guint) perc;
 	}
 
 	return origins;
@@ -274,6 +277,20 @@ gs_plugin_setup (GsPlugin *plugin, GCancellable *cancellable, GError **error)
 		}
 	}
 
+	/* add keyword for non-package sources */
+	for (i = 0; i < items->len; i++) {
+		AsBundle *bundle;
+		app = g_ptr_array_index (items, i);
+		bundle = as_app_get_bundle_default (app);
+		if (bundle == NULL)
+			continue;
+		g_debug ("Adding keyword '%s' to %s",
+			 as_bundle_kind_to_string (as_bundle_get_kind (bundle)),
+			 as_app_get_unique_id (app));
+		as_app_add_keyword (app, NULL,
+				    as_bundle_kind_to_string (as_bundle_get_kind (bundle)));
+	}
+
 	/* fix up these */
 	for (i = 0; i < items->len; i++) {
 		app = g_ptr_array_index (items, i);
@@ -305,21 +322,35 @@ gs_plugin_refine_from_id (GsPlugin *plugin,
 			  GError **error)
 {
 	GsPluginData *priv = gs_plugin_get_data (plugin);
-	const gchar *id;
+	const gchar *unique_id;
 	AsApp *item;
 
 	/* unfound */
 	*found = FALSE;
 
 	/* find anything that matches the ID */
-	id = gs_app_get_id (app);
-	if (id == NULL)
+	unique_id = gs_app_get_unique_id (app);
+	if (unique_id == NULL)
 		return TRUE;
 
 	/* nothing found */
-	item = as_store_get_app_by_id (priv->store, id);
-	if (item == NULL)
+	g_debug ("searching appstream for %s", unique_id);
+	item = as_store_get_app_by_unique_id (priv->store, unique_id,
+					      AS_STORE_SEARCH_FLAG_USE_WILDCARDS);
+	if (item == NULL) {
+		guint i;
+		GPtrArray *apps;
+		g_debug ("no app with ID %s found in appstream", unique_id);
+		apps = as_store_get_apps (priv->store);
+		for (i = 0; i < apps->len; i++) {
+			item = g_ptr_array_index (apps, i);
+			if (g_strcmp0 (as_app_get_id (item), gs_app_get_id (app)) != 0)
+				continue;
+			g_debug ("possible match: %s",
+				 as_app_get_unique_id (item));
+		}
 		return TRUE;
+	}
 
 	/* set new properties */
 	if (!gs_appstream_refine_app (plugin, app, item, error))
@@ -359,14 +390,15 @@ gs_plugin_refine_from_pkgname (GsPlugin *plugin,
 }
 
 static GsApp *
-gs_plugin_appstream_create_app (GsPlugin *plugin, const gchar *id)
+gs_plugin_appstream_create_app (GsPlugin *plugin, AsApp *item)
 {
-	GsApp *app = gs_plugin_cache_lookup (plugin, id);
+	const gchar *unique_id = as_app_get_unique_id (item);
+	GsApp *app = gs_plugin_cache_lookup (plugin, unique_id);
 	if (app == NULL) {
-		app = gs_app_new (id);
+		app = gs_app_new (as_app_get_id (item));
 		gs_app_set_metadata (app, "GnomeSoftware::Creator",
 				     gs_plugin_get_name (plugin));
-		gs_plugin_cache_add (plugin, id, app);
+		gs_plugin_cache_add (plugin, unique_id, app);
 	}
 	return app;
 }
@@ -391,7 +423,7 @@ gs_plugin_add_distro_upgrades (GsPlugin *plugin,
 			continue;
 
 		/* create */
-		app = gs_plugin_appstream_create_app (plugin, as_app_get_id (item));
+		app = gs_plugin_appstream_create_app (plugin, item);
 		gs_app_set_kind (app, AS_APP_KIND_OS_UPGRADE);
 		gs_app_set_state (app, AS_APP_STATE_AVAILABLE);
 		if (!gs_appstream_refine_app (plugin, app, item, error))
@@ -460,8 +492,7 @@ gs_plugin_appstream_add_wildcards (GsPlugin *plugin,
 		/* new app */
 		g_debug ("found %s for wildcard %s",
 			 as_app_get_id (item), id);
-		new = gs_plugin_appstream_create_app (plugin,
-						      as_app_get_id (item));
+		new = gs_plugin_appstream_create_app (plugin, item);
 		if (!gs_appstream_refine_app (plugin, new, item, error))
 			return FALSE;
 		gs_app_list_add (list, new);
@@ -554,8 +585,7 @@ gs_plugin_add_category_apps (GsPlugin *plugin,
 				continue;
 
 			/* add all the data we can */
-			app = gs_plugin_appstream_create_app (plugin,
-							      as_app_get_id (item));
+			app = gs_plugin_appstream_create_app (plugin, item);
 			if (!gs_appstream_refine_app (plugin, app, item, error))
 				return FALSE;
 			gs_app_list_add (list, app);
@@ -591,7 +621,7 @@ gs_plugin_add_search_item (GsPlugin *plugin,
 		return TRUE;
 
 	/* create app */
-	app = gs_plugin_appstream_create_app (plugin, as_app_get_id (item));
+	app = gs_plugin_appstream_create_app (plugin, item);
 	if (!gs_appstream_refine_app (plugin, app, item, error))
 		return FALSE;
 	gs_app_set_match_value (app, match_value);
@@ -651,7 +681,7 @@ gs_plugin_add_installed (GsPlugin *plugin,
 		item = g_ptr_array_index (array, i);
 		if (as_app_get_state (item) == AS_APP_STATE_INSTALLED) {
 			g_autoptr(GsApp) app = NULL;
-			app = gs_plugin_appstream_create_app (plugin, as_app_get_id (item));
+			app = gs_plugin_appstream_create_app (plugin, item);
 			if (!gs_appstream_refine_app (plugin, app, item, error))
 				return FALSE;
 			gs_app_list_add (list, app);
@@ -746,7 +776,7 @@ gs_plugin_add_popular (GsPlugin *plugin,
 			continue;
 		if (!as_app_has_kudo (item, "GnomeSoftware::popular"))
 			continue;
-		app = gs_plugin_appstream_create_app (plugin, as_app_get_id_no_prefix (item));
+		app = gs_plugin_appstream_create_app (plugin, item);
 		gs_app_add_quirk (app, AS_APP_QUIRK_MATCH_ANY_PREFIX);
 		gs_app_list_add (list, app);
 	}
@@ -777,7 +807,7 @@ gs_plugin_add_featured (GsPlugin *plugin,
 			continue;
 		if (as_app_get_metadata_item (item, "GnomeSoftware::FeatureTile-css") == NULL)
 			continue;
-		app = gs_plugin_appstream_create_app (plugin, as_app_get_id_no_prefix (item));
+		app = gs_plugin_appstream_create_app (plugin, item);
 		if (!gs_appstream_refine_app (plugin, app, item, error))
 			return FALSE;
 		gs_app_add_quirk (app, AS_APP_QUIRK_MATCH_ANY_PREFIX);
