@@ -83,12 +83,8 @@ gs_plugin_destroy (GsPlugin *plugin)
 void
 gs_plugin_adopt_app (GsPlugin *plugin, GsApp *app)
 {
-	const gchar *tmp;
-
-	/* this was installed system-wide and picked up by AppStream */
-	tmp = gs_app_get_metadata_item (app, "appstream::source-file");
-	if (tmp != NULL && g_str_has_prefix (tmp, "/usr/share/") &&
-	    gs_app_get_source_default (app) != NULL) {
+	if (gs_app_get_bundle_kind (app) == AS_BUNDLE_KIND_PACKAGE &&
+	    gs_app_get_scope (app) == AS_APP_SCOPE_SYSTEM) {
 		gs_app_set_management_plugin (app, "packagekit");
 		return;
 	}
@@ -323,7 +319,7 @@ gs_plugin_packagekit_refine_from_desktop (GsPlugin *plugin,
 		package = g_ptr_array_index (packages, 0);
 		gs_plugin_packagekit_set_metadata_from_package (plugin, app, package);
 	} else {
-		g_warning ("Failed to find one package for %s, %s, [%d]",
+		g_warning ("Failed to find one package for %s, %s, [%u]",
 			   gs_app_get_id (app), filename, packages->len);
 	}
 	return TRUE;
@@ -860,6 +856,8 @@ gs_plugin_refine (GsPlugin *plugin,
 		tmp = gs_app_get_id (app);
 		if (tmp == NULL)
 			continue;
+		if (gs_app_get_management_plugin (app) != NULL)
+			continue;
 		switch (gs_app_get_kind (app)) {
 		case AS_APP_KIND_DESKTOP:
 			fn = g_strdup_printf ("/usr/share/applications/%s", tmp);
@@ -931,3 +929,25 @@ gs_plugin_refine (GsPlugin *plugin,
 out:
 	return ret;
 }
+
+gboolean
+gs_plugin_refine_app (GsPlugin *plugin,
+		      GsApp *app,
+		      GsPluginRefineFlags flags,
+		      GCancellable *cancellable,
+		      GError **error)
+{
+	g_autoptr(AsProfileTask) ptask = NULL;
+
+	/* only process this app if was created by this plugin */
+	if (g_strcmp0 (gs_app_get_management_plugin (app), "packagekit") != 0)
+		return TRUE;
+
+	/* the scope is always system-wide */
+	if (gs_app_get_scope (app) == AS_APP_SCOPE_UNKNOWN)
+		gs_app_set_scope (app, AS_APP_SCOPE_SYSTEM);
+	if (gs_app_get_bundle_kind (app) == AS_BUNDLE_KIND_UNKNOWN)
+		gs_app_set_bundle_kind (app, AS_BUNDLE_KIND_PACKAGE);
+
+	return TRUE;
+}
