@@ -37,11 +37,11 @@ struct GsPluginData {
 };
 
 typedef struct {
-	gint64		 one_star_count;
-	gint64		 two_star_count;
-	gint64		 three_star_count;
-	gint64		 four_star_count;
-	gint64		 five_star_count;
+	guint64		 one_star_count;
+	guint64		 two_star_count;
+	guint64		 three_star_count;
+	guint64		 four_star_count;
+	guint64		 five_star_count;
 } Histogram;
 
 #define UBUNTU_REVIEWS_SERVER		"https://reviews.ubuntu.com/reviews"
@@ -129,7 +129,7 @@ set_package_stats (GsPlugin *plugin,
 	statement = g_strdup_printf ("INSERT OR REPLACE INTO review_stats (package_name, "
 				     "one_star_count, two_star_count, three_star_count, "
 				     "four_star_count, five_star_count) "
-				     "VALUES ('%s', '%" G_GINT64_FORMAT "', '%" G_GINT64_FORMAT"', '%" G_GINT64_FORMAT "', '%" G_GINT64_FORMAT "', '%" G_GINT64_FORMAT "');",
+				     "VALUES ('%s', '%" G_GUINT64_FORMAT "', '%" G_GUINT64_FORMAT"', '%" G_GUINT64_FORMAT "', '%" G_GUINT64_FORMAT "', '%" G_GUINT64_FORMAT "');",
 				     package_name, histogram->one_star_count, histogram->two_star_count,
 				     histogram->three_star_count, histogram->four_star_count, histogram->five_star_count);
 	result = sqlite3_exec (priv->db, statement, NULL, NULL, &error_msg);
@@ -178,73 +178,14 @@ get_review_stats_sqlite_cb (void *data,
 			    gchar **col_name)
 {
 	Histogram *histogram = (Histogram *) data;
-	histogram->one_star_count = g_ascii_strtoll (argv[0], NULL, 10);
-	histogram->two_star_count = g_ascii_strtoll (argv[1], NULL, 10);
-	histogram->three_star_count = g_ascii_strtoll (argv[2], NULL, 10);
-	histogram->four_star_count = g_ascii_strtoll (argv[3], NULL, 10);
-	histogram->five_star_count = g_ascii_strtoll (argv[4], NULL, 10);
+	histogram->one_star_count = g_ascii_strtoull (argv[0], NULL, 10);
+	histogram->two_star_count = g_ascii_strtoull (argv[1], NULL, 10);
+	histogram->three_star_count = g_ascii_strtoull (argv[2], NULL, 10);
+	histogram->four_star_count = g_ascii_strtoull (argv[3], NULL, 10);
+	histogram->five_star_count = g_ascii_strtoull (argv[4], NULL, 10);
 	return 0;
 }
 
-static gdouble
-pnormaldist (gdouble qn)
-{
-	static gdouble b[11] = { 1.570796288,      0.03706987906,   -0.8364353589e-3,
-				-0.2250947176e-3,  0.6841218299e-5,  0.5824238515e-5,
-				-0.104527497e-5,   0.8360937017e-7, -0.3231081277e-8,
-				 0.3657763036e-10, 0.6936233982e-12 };
-	gdouble w1, w3;
-	int i;
-
-	if (qn < 0 || qn > 1)
-		return 0; // This is an error case
-	if (qn == 0.5)
-		return 0;
-
-	w1 = qn;
-	if (qn > 0.5)
-		w1 = 1.0 - w1;
-	w3 = -log (4.0 * w1 * (1.0 - w1));
-	w1 = b[0];
-	for (i = 1; i < 11; i++)
-		w1 = w1 + (b[i] * pow (w3, i));
-
-	if (qn > 0.5)
-		return sqrt (w1 * w3);
-	else
-		return -sqrt (w1 * w3);
-}
-
-static gdouble
-wilson_score (gdouble value, gint n, gdouble power)
-{
-	gdouble z, phat;
-
-	if (value == 0)
-		return 0;
-
-	z = pnormaldist (1 - power / 2);
-	phat = value / n;
-	return (phat + z * z / (2 * n) - z * sqrt ((phat * (1 - phat) + z * z / (4 * n)) / n)) / (1 + z * z / n);
-}
-
-static gint
-get_rating (gint64 one_star_count, gint64 two_star_count, gint64 three_star_count, gint64 four_star_count, gint64 five_star_count)
-{
-	gint n_ratings;
-
-	n_ratings = one_star_count + two_star_count + three_star_count + four_star_count + five_star_count;
-	if (n_ratings == 0)
-		return -1;
-
-	// Use a Wilson score which is a method of ensuring small numbers of ratings don't give high scores
-	// https://en.wikipedia.org/wiki/Binomial_proportion_confidence_interval
-	return (((wilson_score (one_star_count, n_ratings, 0.1) * -2) +
-		 (wilson_score (two_star_count, n_ratings, 0.1) * -1) +
-		 (wilson_score (four_star_count, n_ratings, 0.1) * 1) +
-		 (wilson_score (five_star_count, n_ratings, 0.1) * 2)) + 3) * 20 - 10;
-}
-
 static gboolean
 get_review_stats (GsPlugin *plugin,
 		  const gchar *package_name,
@@ -275,13 +216,17 @@ get_review_stats (GsPlugin *plugin,
 		return FALSE;
 	}
 
-	*rating = get_rating (histogram.one_star_count, histogram.two_star_count, histogram.three_star_count, histogram.four_star_count, histogram.five_star_count);
+	*rating = gs_utils_get_wilson_rating (histogram.one_star_count,
+					      histogram.two_star_count,
+					      histogram.three_star_count,
+					      histogram.four_star_count,
+					      histogram.five_star_count);
 	review_ratings[0] = 0;
-	review_ratings[1] = histogram.one_star_count;
-	review_ratings[2] = histogram.two_star_count;
-	review_ratings[3] = histogram.three_star_count;
-	review_ratings[4] = histogram.four_star_count;
-	review_ratings[5] = histogram.five_star_count;
+	review_ratings[1] = (gint) histogram.one_star_count;
+	review_ratings[2] = (gint) histogram.two_star_count;
+	review_ratings[3] = (gint) histogram.three_star_count;
+	review_ratings[4] = (gint) histogram.four_star_count;
+	review_ratings[5] = (gint) histogram.five_star_count;
 
 	return TRUE;
 }
@@ -301,11 +246,11 @@ parse_histogram (const gchar *text, Histogram *histogram)
 	array = json_node_get_array (json_parser_get_root (parser));
 	if (json_array_get_length (array) != 5)
 		return FALSE;
-	histogram->one_star_count = json_array_get_int_element (array, 0);
-	histogram->two_star_count = json_array_get_int_element (array, 1);
-	histogram->three_star_count = json_array_get_int_element (array, 2);
-	histogram->four_star_count = json_array_get_int_element (array, 3);
-	histogram->five_star_count = json_array_get_int_element (array, 4);
+	histogram->one_star_count = (guint64) json_array_get_int_element (array, 0);
+	histogram->two_star_count = (guint64) json_array_get_int_element (array, 1);
+	histogram->three_star_count = (guint64) json_array_get_int_element (array, 2);
+	histogram->four_star_count = (guint64) json_array_get_int_element (array, 3);
+	histogram->five_star_count = (guint64) json_array_get_int_element (array, 4);
 
 	return TRUE;
 }
@@ -495,7 +440,7 @@ download_review_stats (GsPlugin *plugin, GCancellable *cancellable, GError **err
 		g_set_error (error,
 			     GS_PLUGIN_ERROR,
 			     GS_PLUGIN_ERROR_FAILED,
-			     "Failed to download review stats, server returned status code %d",
+			     "Failed to download review stats, server returned status code %u",
 			     status_code);
 		return FALSE;
 	}
@@ -645,7 +590,7 @@ parse_date_time (const gchar *text)
 }
 
 static gboolean
-parse_review (GsReview *review, const gchar *our_username, JsonNode *node)
+parse_review (AsReview *review, const gchar *our_username, JsonNode *node)
 {
 	JsonObject *object;
 	gint64 star_rating;
@@ -657,17 +602,17 @@ parse_review (GsReview *review, const gchar *our_username, JsonNode *node)
 	object = json_node_get_object (node);
 
 	if (g_strcmp0 (our_username, json_object_get_string_member (object, "reviewer_username")) == 0)
-		gs_review_add_flags (review, GS_REVIEW_FLAG_SELF);
-	gs_review_set_reviewer (review, json_object_get_string_member (object, "reviewer_displayname"));
-	gs_review_set_summary (review, json_object_get_string_member (object, "summary"));
-	gs_review_set_text (review, json_object_get_string_member (object, "review_text"));
-	gs_review_set_version (review, json_object_get_string_member (object, "version"));
+		as_review_add_flags (review, AS_REVIEW_FLAG_SELF);
+	as_review_set_reviewer_name (review, json_object_get_string_member (object, "reviewer_displayname"));
+	as_review_set_summary (review, json_object_get_string_member (object, "summary"));
+	as_review_set_description (review, json_object_get_string_member (object, "review_text"));
+	as_review_set_version (review, json_object_get_string_member (object, "version"));
 	star_rating = json_object_get_int_member (object, "rating");
 	if (star_rating > 0)
-		gs_review_set_rating (review, star_rating * 20 - 10);
-	gs_review_set_date (review, parse_date_time (json_object_get_string_member (object, "date_created")));
+		as_review_set_rating (review, (gint) (star_rating * 20 - 10));
+	as_review_set_date (review, parse_date_time (json_object_get_string_member (object, "date_created")));
 	id_string = g_strdup_printf ("%" G_GINT64_FORMAT, json_object_get_int_member (object, "id"));
-	gs_review_add_metadata (review, "ubuntu-id", id_string);
+	as_review_add_metadata (review, "ubuntu-id", id_string);
 
 	return TRUE;
 }
@@ -688,10 +633,10 @@ parse_reviews (GsPlugin *plugin, JsonParser *parser, GsApp *app, GCancellable *c
 		return FALSE;
 	array = json_node_get_array (json_parser_get_root (parser));
 	for (i = 0; i < json_array_get_length (array); i++) {
-		g_autoptr(GsReview) review = NULL;
+		g_autoptr(AsReview) review = NULL;
 
 		/* Read in from JSON... (skip bad entries) */
-		review = gs_review_new ();
+		review = as_review_new ();
 		if (parse_review (review, consumer_key, json_array_get_element (array, i)))
 			gs_app_add_review (app, review);
 	}
@@ -701,7 +646,7 @@ parse_reviews (GsPlugin *plugin, JsonParser *parser, GsApp *app, GCancellable *c
 
 static gboolean
 download_reviews (GsPlugin *plugin, GsApp *app,
-		  const gchar *package_name, gint page_number,
+		  const gchar *package_name, guint page_number,
 		  GCancellable *cancellable, GError **error)
 {
 	const gchar *language;
@@ -711,7 +656,7 @@ download_reviews (GsPlugin *plugin, GsApp *app,
 
 	/* Get the review stats using HTTP */
 	language = gs_plugin_get_language (plugin);
-	path = g_strdup_printf ("/api/1.0/reviews/filter/%s/any/any/any/%s/page/%d/",
+	path = g_strdup_printf ("/api/1.0/reviews/filter/%s/any/any/any/%s/page/%u/",
 				language, package_name, page_number + 1);
 	if (!send_review_request (plugin, SOUP_METHOD_GET, path,
 				  NULL, FALSE,
@@ -722,7 +667,7 @@ download_reviews (GsPlugin *plugin, GsApp *app,
 		g_set_error (error,
 			     GS_PLUGIN_ERROR,
 			     GS_PLUGIN_ERROR_FAILED,
-			     "Failed to download reviews, server returned status code %d",
+			     "Failed to download reviews, server returned status code %u",
 			     status_code);
 		return FALSE;
 	}
@@ -842,7 +787,7 @@ add_int_member (JsonBuilder *builder, const gchar *name, gint64 value)
 gboolean
 gs_plugin_review_submit (GsPlugin *plugin,
 			 GsApp *app,
-			 GsReview *review,
+			 AsReview *review,
 			 GCancellable *cancellable,
 			 GError **error)
 {
@@ -858,7 +803,7 @@ gs_plugin_review_submit (GsPlugin *plugin,
 	g_autoptr(JsonParser) result = NULL;
 
 	/* Ubuntu reviews require a summary and description - just make one up for now */
-	rating = gs_review_get_rating (review);
+	rating = as_review_get_rating (review);
 	if (rating > 80)
 		n_stars = 5;
 	else if (rating > 60)
@@ -879,12 +824,12 @@ gs_plugin_review_submit (GsPlugin *plugin,
 	request = json_builder_new ();
 	json_builder_begin_object (request);
 	add_string_member (request, "package_name", gs_app_get_source_default (app));
-	add_string_member (request, "summary", gs_review_get_summary (review));
-	add_string_member (request, "review_text", gs_review_get_text (review));
+	add_string_member (request, "summary", as_review_get_summary (review));
+	add_string_member (request, "review_text", as_review_get_description (review));
 	add_string_member (request, "language", language);
 	add_string_member (request, "origin", priv->origin);
 	add_string_member (request, "distroseries", priv->distroseries);
-	add_string_member (request, "version", gs_review_get_version (review));
+	add_string_member (request, "version", as_review_get_version (review));
 	add_int_member (request, "rating", n_stars);
 	add_string_member (request, "arch_tag", architecture);
 	json_builder_end_object (request);
@@ -898,7 +843,7 @@ gs_plugin_review_submit (GsPlugin *plugin,
 		g_set_error (error,
 			     GS_PLUGIN_ERROR,
 			     GS_PLUGIN_ERROR_FAILED,
-			     "Failed to submit review, server returned status code %d",
+			     "Failed to submit review, server returned status code %u",
 			     status_code);
 		return FALSE;
 	}
@@ -915,7 +860,7 @@ gs_plugin_review_submit (GsPlugin *plugin,
 gboolean
 gs_plugin_review_report (GsPlugin *plugin,
 			 GsApp *app,
-			 GsReview *review,
+			 AsReview *review,
 			 GCancellable *cancellable,
 			 GError **error)
 {
@@ -926,7 +871,7 @@ gs_plugin_review_report (GsPlugin *plugin,
 	guint status_code;
 
 	/* Can only modify Ubuntu reviews */
-	review_id = gs_review_get_metadata_item (review, "ubuntu-id");
+	review_id = as_review_get_metadata_item (review, "ubuntu-id");
 	if (review_id == NULL)
 		return TRUE;
 
@@ -944,12 +889,12 @@ gs_plugin_review_report (GsPlugin *plugin,
 		g_set_error (error,
 			     GS_PLUGIN_ERROR,
 			     GS_PLUGIN_ERROR_FAILED,
-			     "Failed to report review, server returned status code %d",
+			     "Failed to report review, server returned status code %u",
 			     status_code);
 		return FALSE;
 	}
 
-	gs_review_add_flags (review, GS_REVIEW_FLAG_VOTED);
+	as_review_add_flags (review, AS_REVIEW_FLAG_VOTED);
 	return TRUE;
 }
 
@@ -975,7 +920,7 @@ set_review_usefulness (GsPlugin *plugin,
 		g_set_error (error,
 			     GS_PLUGIN_ERROR,
 			     GS_PLUGIN_ERROR_FAILED,
-			     "Got status code %d from reviews.ubuntu.com",
+			     "Got status code %u from reviews.ubuntu.com",
 			     status_code);
 		return FALSE;
 	}
@@ -986,49 +931,49 @@ set_review_usefulness (GsPlugin *plugin,
 gboolean
 gs_plugin_review_upvote (GsPlugin *plugin,
 			 GsApp *app,
-			 GsReview *review,
+			 AsReview *review,
 			 GCancellable *cancellable,
 			 GError **error)
 {
 	const gchar *review_id;
 
 	/* Can only modify Ubuntu reviews */
-	review_id = gs_review_get_metadata_item (review, "ubuntu-id");
+	review_id = as_review_get_metadata_item (review, "ubuntu-id");
 	if (review_id == NULL)
 		return TRUE;
 
 	if (!set_review_usefulness (plugin, review_id, TRUE, cancellable, error))
 		return FALSE;
 
-	gs_review_add_flags (review, GS_REVIEW_FLAG_VOTED);
+	as_review_add_flags (review, AS_REVIEW_FLAG_VOTED);
 	return TRUE;
 }
 
 gboolean
 gs_plugin_review_downvote (GsPlugin *plugin,
 			   GsApp *app,
-			   GsReview *review,
+			   AsReview *review,
 			   GCancellable *cancellable,
 			   GError **error)
 {
 	const gchar *review_id;
 
 	/* Can only modify Ubuntu reviews */
-	review_id = gs_review_get_metadata_item (review, "ubuntu-id");
+	review_id = as_review_get_metadata_item (review, "ubuntu-id");
 	if (review_id == NULL)
 		return TRUE;
 
 	if (!set_review_usefulness (plugin, review_id, FALSE, cancellable, error))
 		return FALSE;
 
-	gs_review_add_flags (review, GS_REVIEW_FLAG_VOTED);
+	as_review_add_flags (review, AS_REVIEW_FLAG_VOTED);
 	return TRUE;
 }
 
 gboolean
 gs_plugin_review_remove (GsPlugin *plugin,
 			 GsApp *app,
-			 GsReview *review,
+			 AsReview *review,
 			 GCancellable *cancellable,
 			 GError **error)
 {
@@ -1037,7 +982,7 @@ gs_plugin_review_remove (GsPlugin *plugin,
 	guint status_code;
 
 	/* Can only modify Ubuntu reviews */
-	review_id = gs_review_get_metadata_item (review, "ubuntu-id");
+	review_id = as_review_get_metadata_item (review, "ubuntu-id");
 	if (review_id == NULL)
 		return TRUE;
 
@@ -1052,7 +997,7 @@ gs_plugin_review_remove (GsPlugin *plugin,
 		g_set_error (error,
 			     GS_PLUGIN_ERROR,
 			     GS_PLUGIN_ERROR_FAILED,
-			     "Failed to remove review, server returned status code %d",
+			     "Failed to remove review, server returned status code %u",
 			     status_code);
 		return FALSE;
 	}
